import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table} from '@/components/Common-Library'
import Api from '@/service/api'
import mBrtdck from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class BrtdckScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'brtdck'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mBrtdck()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('brtdck/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }

    glemod_glelstHeader=[
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"dbtcdt",
    		key:"dbtcdt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dbtcdt,r2.dbtcdt),
    	},
    	{
    		title:<Label itext="账号" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="起息日" />, 
    		dataIndex:"valdat",
    		key:"valdat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.valdat,r2.valdat),
    	},
    	{
    		title:<Label itext="科目号" />, 
    		dataIndex:"trmtyp",
    		key:"trmtyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.trmtyp,r2.trmtyp),
    	},
    	{
    		title:<Label itext="PN序号" />, 
    		dataIndex:"prn",
    		key:"prn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.prn,r2.prn),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rat",
    		key:"rat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rat,r2.rat),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fctsgn",
    		key:"fctsgn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fctsgn,r2.fctsgn),
    	},
    ]
    docmod_doclstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"role",
    		key:"role",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.role,r2.role),
    	},
    	{
    		title:<Label itext="码值" />, 
    		dataIndex:"id",
    		key:"id",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.id,r2.id),
    	},
    	{
    		title:<Label itext="凭证名称" />, 
    		dataIndex:"docnam",
    		key:"docnam",
    		width:200,
    		sorter: (r1,r2)=>ColSorter(r1.docnam,r2.docnam),
    	},
    	{
    		title:<Label itext="凭证类型" />, 
    		dataIndex:"cortyp",
    		key:"cortyp",
    		width:150,
    		sorter: (r1,r2)=>ColSorter(r1.cortyp,r2.cortyp),
    	},
    	{
    		title:<Label itext="出具/发送" />, 
    		dataIndex:"mdtflg",
    		key:"mdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.mdtflg,r2.mdtflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"ptainr",
    		key:"ptainr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.ptainr,r2.ptainr),
    	},
    ]
    fegmod_feslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="费用代码" />, 
    		dataIndex:"feecod",
    		key:"feecod",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feecod,r2.feecod),
    	},
    	{
    		title:<Label itext="费用名称" />, 
    		dataIndex:"feetxt",
    		key:"feetxt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feetxt,r2.feetxt),
    	},
    	{
    		title:<Label itext="收费币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="应收金额" />, 
    		dataIndex:"basamt",
    		key:"basamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.basamt,r2.basamt),
    	},
    	{
    		title:<Label itext="实收金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="现收/缓收" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="内扣/外收" />, 
    		dataIndex:"payflg",
    		key:"payflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.payflg,r2.payflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.payflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfcur",
    		key:"xrfcur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfcur,r2.xrfcur),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfamt",
    		key:"xrfamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfamt,r2.xrfamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"feeacc",
    		key:"feeacc",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feeacc,r2.feeacc),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fepinr",
    		key:"fepinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fepinr,r2.fepinr),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rolptyinr",
    		key:"rolptyinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rolptyinr,r2.rolptyinr),
    	},
    ]
    glgmod_glslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"debcdtflg",
    		key:"debcdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.debcdtflg,r2.debcdtflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.debcdtflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="结算方式" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp2.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="账户" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="原币种" />, 
    		dataIndex:"acccur",
    		key:"acccur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.acccur,r2.acccur),
    	},
    	{
    		title:<Label itext="原金额" />, 
    		dataIndex:"accamt",
    		key:"accamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.accamt,r2.accamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"actflg",
    		key:"actflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.actflg,r2.actflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fmtamt",
    		key:"fmtamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fmtamt,r2.fmtamt),
    	},
    ]


    //按钮事件
    onChk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/chk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_ast= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/setmod_ast',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSav= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/sav',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_recal= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/setmod_recal',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onOthp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/othp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPed= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/ped',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetinstxm_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/setinstxm_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onDocdis_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/docdis_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts2_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/pts2_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts3_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/pts3_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPrbp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/prbp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onExi= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/exi',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onGlemod_rebook= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/glemod_rebook',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_butshw= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/trndoc_butshw',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_feedet= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/setmod_feedet',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_reldoc= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtdck/trndoc_reldoc',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div className="transPage">

	
	<Label itext="信用证编号" trn="brtdck" />	
	<InputItem InputProps={bind("ownref1")}  maxLength={16}  desp="Reference" path="/lidgrp/rec/ownref" />

	
	<Label itext="信用证余额" trn="brtdck" />	
	<SelectItem InputProps={bind("opn11_cur")} code={CodeTable.cur}  desp="Currency" path="/lidgrp/cbs/opn1/cur"/>
	<InputItem InputProps={bind("opn11_amt")}   desp="Balance" path="/lidgrp/cbs/opn1/amt" />

	
	<Label itext="单据参考号" trn="brtdck" />	
	<InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Own Reference BR Number" path="/brdgrp/rec/ownref" />
	<InputItem InputProps={bind("nam")}  maxLength={40}  desp="Name of Bill Contract" path="/brdgrp/rec/nam" />

	
	<Label itext="申请人" trn="brtdck" />	

	
	<Label itext="编号" trn="brtdck" />	
	<InputItem InputProps={bind("pts_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/apl/pts/ref" />

	
	<Label itext="到期日" trn="brtdck" />	
	<DatePickerItem InputProps={bind("expdat")}  desp="Date of Expiry" path="/lidgrp/rec/expdat" />
	<InputItem InputProps={bind("pts_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/apl/pts/nam" />

	
	<Label itext="单据金额" trn="brtdck" />	
	<SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/brdgrp/cbs/max/cur"/>
	<InputItem InputProps={bind("max_amt")}   desp="Balance" path="/brdgrp/cbs/max/amt" />

	
	<Label itext="受益人" trn="brtdck" />	

	
	<Label itext="编号" trn="brtdck" />	
	<InputItem InputProps={bind("pts1_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/ben/pts/ref" />

	
	<Label itext="单据余额" trn="brtdck" />	
	<InputItem InputProps={bind("opn1_cur")}  maxLength={3}  desp="Currency" path="/brdgrp/cbs/opn1/cur" />
	<InputItem InputProps={bind("opn1_amt")}   desp="Balance" path="/brdgrp/cbs/opn1/amt" />
	<InputItem InputProps={bind("pts1_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/ben/pts/nam" />

	
	<Label itext="到单日期" trn="brtdck" />	
	<DatePickerItem InputProps={bind("rcvdat")}  desp="Date of Receipt of Documents" path="/brdgrp/rec/rcvdat" />

	
	<Label itext="通知到单日期" trn="brtdck" />	
	<DatePickerItem InputProps={bind("advdat")}  desp="Date of Advice of Payment" path="/brdgrp/rec/advdat" />

	
	<Label itext="远期单据到期日" trn="brtdck" />	
	<Label value={this.model.matp_mattxtlab}   desp="Label for MATTXT" path="/brtp/matp/mattxtlab" />
	<DatePickerItem InputProps={bind("matdat")}  desp="Maturity Date" path="/brdgrp/rec/matdat" />

	
	<Label itext="交单行" trn="brtdck" />	

	
	<Label itext="编号" trn="brtdck" />	
	<InputItem InputProps={bind("pts2_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/prb/pts/ref" />

	
	<Label itext="Document Type" trn="brtdck" />	
	<SelectItem InputProps={bind("docflg")}   desp="Usance, Sight or Mixed" path="/brdgrp/rec/docflg"/>

	
	<Label itext="Presented by" trn="brtdck" />	
	<SelectItem InputProps={bind("docprbrol")}   desp="Presented by" path="/brdgrp/rec/docprbrol"/>
	<SelectItem InputProps={bind("docflg")}   desp="Usance, Sight or Mixed" path="/brdgrp/rec/docflg"/>

	
	<Label itext="单据类型" trn="brtdck" />	
	<InputItem InputProps={bind("pts2_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/prb/pts/nam" />

	
	<Label itext="Document Amount" trn="brtdck" />	
	<SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/brdgrp/cbs/max/cur"/>
	<InputItem InputProps={bind("max_amt")}   desp="Balance" path="/brdgrp/cbs/max/amt" />

	
	<Label itext="单据状态" trn="brtdck" />	
	<SelectItem InputProps={bind("docsta")} code={CodeTable.docsta}  desp="Document Set Status" path="/brdgrp/rec/docsta"/>
	<InputItem InputProps={bind("pts2_extkey")}  maxLength={16}  desp="客户编号" path="/brdgrp/prb/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onPrbp_sel} desp="查询" path="/brtp/prbp/sel">
		<Label   itext="查询"/>
	</Button>
	<Label value={this.model.oridoclab}   desp="Label original" path="/oridoclab" />
	<InputItem InputProps={bind("max1_amt")}   desp="Balance" path="/oldbrdgrp/cbs/max/amt" />
	<TextAreaItem InputProps={bind("pts2_adrblk")} desp="SWIFT地址" path="/brdgrp/prb/pts/adrblk"/>

	
	<Label itext="附加金额" trn="brtdck" />	
	<SelectItem InputProps={bind("opn2_cur")} code={CodeTable.curtxt}  desp="Currency" path="/brdgrp/cbs/opn2/cur"/>
	<InputItem InputProps={bind("max2_amt")}   desp="Balance" path="/brdgrp/cbs/max2/amt" />
	<Label value={this.model.oriaddlab}   desp="Label original" path="/oriaddlab" />
	<InputItem InputProps={bind("max21_amt")}   desp="Balance" path="/oldbrdgrp/cbs/max2/amt" />

	
	<Label itext="Presentation Date" trn="brtdck" />	
	<DatePickerItem InputProps={bind("predat")}  desp="Presentation Date" path="/brdgrp/rec/predat" />

	
	<Label itext="Received on" trn="brtdck" />	
	<DatePickerItem InputProps={bind("rcvdat")}  desp="Date of Receipt of Documents" path="/brdgrp/rec/rcvdat" />

	
	<Label itext="Payer" trn="brtdck" />	
	<SelectItem InputProps={bind("payrol")}   desp="Payer" path="/brdgrp/rec/payrol"/>

	
	<Label itext="Maturity Date" trn="brtdck" />	
	<DatePickerItem InputProps={bind("matdat")}  desp="Maturity Date" path="/brdgrp/rec/matdat" />

	
	<Label itext="Shipped on" trn="brtdck" />	
	<DatePickerItem InputProps={bind("shpdat")}  desp="Date of Shipment" path="/brdgrp/rec/shpdat" />
	<InputItem InputProps={bind("pts3_extkey")}  maxLength={16}  desp="客户编号" path="/brtp/oth/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onOthp_sel} desp="查询" path="/brtp/othp/sel">
		<Label   itext="查询"/>
	</Button>

	
	<Label itext="Letter day" trn="brtdck" />	

	
	<Label itext="Maturity Period" trn="brtdck" />	
	<TextAreaItem InputProps={bind("pts3_adrblk")} desp="SWIFT地址" path="/brtp/oth/pts/adrblk"/>
	<TextAreaItem InputProps={bind("blk_matper")} desp="Maturity Period" path="/brdgrp/blk/matper"/>

	
	<Label itext="Applicant Reference" trn="brtdck" />	
	<CheckboxItem InputProps={bind("dscinsflg")}  desp="Enter Docs, Discrep. and Instructions" path="/brdgrp/rec/dscinsflg" />
	<InputItem InputProps={bind("aplref")}  maxLength={16}  desp="Applicant Reference" path="/lidgrp/rec/aplref" />
	<InputItem InputProps={bind("utlnbr")}   desp="Count of Received Document Sets" path="/lidgrp/rec/utlnbr" />

	
	<Label itext="Previous Drawings under this L/C" trn="brtdck" />	
	<CheckboxItem InputProps={bind("brtp_setnowflg")}  desp="Register to Send and Settle Document" path="/brtp/setnowflg" />

	
	<Label itext="不符点" trn="brtdck" />	
	<CheckboxItem InputProps={bind("igndisflg")}  desp="Ignore Discrepancies" path="/brdgrp/rec/igndisflg" />
	<TextAreaItem InputProps={bind("blk_docdis")} desp="Discrepancies" path="/brdgrp/blk/docdis"/>
	<Button  type="primary" icon="search" onClick={this.onDocdis_buttxmsel} desp="..." path="/brtp/docdis/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<CheckboxItem InputProps={bind("blk_docdisflg")}  desp="discrepancies modified" path="/brdgrp/blk/docdisflg" />

	
	<Label itext="收到的通知类型" trn="brtdck" />	
	<SelectItem InputProps={bind("advtyp")} code={CodeTable.advtyp}  desp="Type of Advice Received" path="/brdgrp/rec/advtyp"/>

	
	<Label itext="注释和结论" trn="brtdck" />	

	
	<Label itext="付款日期" trn="brtdck" />	
	<DatePickerItem InputProps={bind("totdat")}  desp="Date to be Paid" path="/brdgrp/rec/totdat" />
	<TextAreaItem InputProps={bind("blk_comcon")} desp="Comments and Conclusions" path="/brdgrp/blk/comcon"/>

	
	<Label itext="Discrepancy Advice Dated" trn="brtdck" />	
	<DatePickerItem InputProps={bind("disdat")}  desp="Date of Discrepancy Advice" path="/brdgrp/rec/disdat" />
	<CheckboxItem InputProps={bind("approvcod")}  desp="Documents on Approval Basis" path="/brdgrp/rec/approvcod" />

	
	<Label itext="结算指示" trn="brtdck" />	
	<TextAreaItem InputProps={bind("blk_setinsbr")} desp="Settlement Instructions BR" path="/brdgrp/blk/setinsbr"/>
	<Button  type="primary" icon="search" onClick={this.onSetinstxm_buttxmsel} desp="..." path="/brtp/setinstxm/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<Label value={this.model.docgrdm_docdsclab}   desp="Label of document description" path="/brtp/docgrdm/docdsclab" />
	<CheckboxItem InputProps={bind("brtp_cre752flg")}  desp="Create 752" path="/brtp/cre752flg" />

	
	<Label itext="Further Identification" trn="brtdck" />	
	<SelectItem InputProps={bind("brtp_furide")}   desp="MT752: Further Indentification" path="/brtp/furide"/>
	<CheckboxItem InputProps={bind("brtp_cre732flg")}  desp="Create MT 732" path="/brtp/cre732flg" />

	
	<Label itext="结算金额" trn="brtdck" />	
	<SelectItem InputProps={bind("setmod_doccur")} code={CodeTable.curtxt}  desp="document currency" path="/setmod/doccur"/>
	<InputItem InputProps={bind("setmod_docamt")}   desp="document amount" path="/setmod/docamt" />
	<Button  type="primary"  onClick={this.onSetmod_feedet} desp="重算金额" path="/setmod/feedet">
		<Label   itext="重算金额"/>
	</Button>
	<Button  type="primary"  onClick={this.onSetmod_ast} desp="加载账务" path="/setmod/ast">
		<Label   itext="加载账务"/>
	</Button>

	
	<Label itext="FEEMAC" trn="brtdck" />	
	<InputItem InputProps={bind("setmod_feemac")}  maxLength={200}  desp="FEEMAC" path="/setmod/feemac" />
	<Button  type="primary"  onClick={this.onSetmod_recal} desp="重算账务" path="/setmod/recal">
		<Label   itext="重算账务"/>
	</Button>

	
	<Label itext="费用明细" trn="brtdck" />	

	
	<Label itext="SETMAC" trn="brtdck" />	
	<InputItem InputProps={bind("setmod_setmac")}  maxLength={200}  desp="SETMAC" path="/setmod/setmac" />
	<Table rowKey="inr" columns={this.fegmod_feslstHeader}  dataSource={this.model.fegmod_feslst}   path="/setmod/setfeg/fegmod/feslst"/>

	
	<Label itext="账务明细" trn="brtdck" />	
	<Table rowKey="inr" columns={this.glgmod_glslstHeader}  dataSource={this.model.glgmod_glslst}   path="/setmod/setglg/glgmod/glslst"/>

	
	<Label itext="会计分录" trn="brtdck" />	
	<Button  type="primary"  onClick={this.onGlemod_rebook} desp="分录加载" path="/setmod/glemod/rebook">
		<Label   itext="分录加载"/>
	</Button>
	<Table rowKey="inr" columns={this.glemod_glelstHeader}  dataSource={this.model.glemod_glelst}   path="/setmod/glemod/glelst"/>

	
	<Label itext="面函码值" trn="brtdck" />	
	<InputItem InputProps={bind("trndoc_doccod")}  maxLength={16}  desp="面函码值" path="/trnmod/trndoc/doccod" />

	
	<Label itext="Per Medium" trn="brtdck" />	
	<InputItem InputProps={bind("trndoc_cortyp")}  maxLength={3}  desp="Per Medium" path="/trnmod/trndoc/cortyp" />
	<Button  type="primary"  onClick={this.onTrndoc_reldoc} desp="面函加载" path="/trnmod/trndoc/reldoc">
		<Label   itext="面函加载"/>
	</Button>
	<Button  type="primary"  onClick={this.onTrndoc_butshw} desp="show doc." path="/trnmod/trndoc/butshw">
		<Label   itext="展示"/>
	</Button>

	
	<Label itext="面函路径" trn="brtdck" />	
	<InputItem InputProps={bind("trndoc_docpth")}  maxLength={100}  desp="面函路径" path="/trnmod/trndoc/docpth" />
	<Table rowKey="inr" columns={this.docmod_doclstHeader}  dataSource={this.model.docmod_doclst}   path="/trnmod/trndoc/docmod/doclst"/>

	
	<Label itext="唯一编号" trn="brtdck" />	
	<InputItem InputProps={bind("spt_inr")}  maxLength={8}  desp="唯一编号" path="/sysmod/spt/inr" />

	
	<Label itext="A" trn="brtdck" />	
	<InputItem InputProps={bind("trndoc_doctrestm")}   desp="Document tree" path="/trnmod/trndoc/doctrestm" />
	<Button  type="primary"  onClick={this.onTrndoc_butadd} desp="Details" path="/trnmod/trndoc/butadd">
		<Label   itext="B"/>
	</Button>
	<Button  type="primary"  onClick={this.onTrndoc_butnew} desp="New Entry" path="/trnmod/trndoc/butnew">
		<Label   itext="C"/>
	</Button>
	<Button  icon="delete" onClick={this.onTrndoc_butdel} desp="Delete Entry" path="/trnmod/trndoc/butdel">
		<Label   itext="D"/>
	</Button>
	<CheckboxItem InputProps={bind("trndoc_shwinc")}  desp="Show Incoming Messages" path="/trnmod/trndoc/shwinc" />
	<CheckboxItem InputProps={bind("trndoc_shwout")}  desp="Show Outgoing Messages" path="/trnmod/trndoc/shwout" />
	<CheckboxItem InputProps={bind("trndoc_shwoutint")}  desp="Show Internal Messages" path="/trnmod/trndoc/shwoutint" />
	<Button  type="primary"  onClick={this.onTrndoc_butatt} desp="Attach" path="/trnmod/trndoc/butatt">
		<Label   itext="E"/>
	</Button>
	<InputItem InputProps={bind("trndoc_condocstm")}   desp="Connected Documents" path="/trnmod/trndoc/condocstm" />
	<Button  type="primary" icon="save"
		  onClick={this.onSav} desp="Save" path="/mtabut/sav">
		<Label   itext="提交"/>
	</Button>
	<Button  type="primary"  onClick={this.onChk} desp="Check" path="/mtabut/chk">
		<Label   itext="检核"/>
	</Button>
	<Button  type="primary"  onClick={this.onPed} desp="暂存" path="/mtabut/ped">
		<Label   itext="暂存"/>
	</Button>
	<Button  type="primary"  onClick={this.onExi} desp="Exit" path="/mtabut/exi">
		<Label   itext="退出"/>
	</Button>
		</div>
		)
	}
}
