import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table} from '@/components/Common-Library'
import Api from '@/service/api'
import mLitadd from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class LitaddScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'litadd'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mLitadd()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('litadd/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }

    glemod_glelstHeader=[
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"dbtcdt",
    		key:"dbtcdt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dbtcdt,r2.dbtcdt),
    	},
    	{
    		title:<Label itext="账号" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="起息日" />, 
    		dataIndex:"valdat",
    		key:"valdat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.valdat,r2.valdat),
    	},
    	{
    		title:<Label itext="科目号" />, 
    		dataIndex:"trmtyp",
    		key:"trmtyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.trmtyp,r2.trmtyp),
    	},
    	{
    		title:<Label itext="PN序号" />, 
    		dataIndex:"prn",
    		key:"prn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.prn,r2.prn),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rat",
    		key:"rat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rat,r2.rat),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fctsgn",
    		key:"fctsgn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fctsgn,r2.fctsgn),
    	},
    ]
    docmod_doclstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"role",
    		key:"role",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.role,r2.role),
    	},
    	{
    		title:<Label itext="码值" />, 
    		dataIndex:"id",
    		key:"id",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.id,r2.id),
    	},
    	{
    		title:<Label itext="凭证名称" />, 
    		dataIndex:"docnam",
    		key:"docnam",
    		width:200,
    		sorter: (r1,r2)=>ColSorter(r1.docnam,r2.docnam),
    	},
    	{
    		title:<Label itext="凭证类型" />, 
    		dataIndex:"cortyp",
    		key:"cortyp",
    		width:150,
    		sorter: (r1,r2)=>ColSorter(r1.cortyp,r2.cortyp),
    	},
    	{
    		title:<Label itext="出具/发送" />, 
    		dataIndex:"mdtflg",
    		key:"mdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.mdtflg,r2.mdtflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"ptainr",
    		key:"ptainr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.ptainr,r2.ptainr),
    	},
    ]
    fegmod_feslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="费用代码" />, 
    		dataIndex:"feecod",
    		key:"feecod",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feecod,r2.feecod),
    	},
    	{
    		title:<Label itext="费用名称" />, 
    		dataIndex:"feetxt",
    		key:"feetxt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feetxt,r2.feetxt),
    	},
    	{
    		title:<Label itext="收费币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="应收金额" />, 
    		dataIndex:"basamt",
    		key:"basamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.basamt,r2.basamt),
    	},
    	{
    		title:<Label itext="实收金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="现收/缓收" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="内扣/外收" />, 
    		dataIndex:"payflg",
    		key:"payflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.payflg,r2.payflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.payflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfcur",
    		key:"xrfcur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfcur,r2.xrfcur),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfamt",
    		key:"xrfamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfamt,r2.xrfamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"feeacc",
    		key:"feeacc",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feeacc,r2.feeacc),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fepinr",
    		key:"fepinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fepinr,r2.fepinr),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rolptyinr",
    		key:"rolptyinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rolptyinr,r2.rolptyinr),
    	},
    ]
    glgmod_glslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"debcdtflg",
    		key:"debcdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.debcdtflg,r2.debcdtflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.debcdtflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="结算方式" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp2.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="账户" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="原币种" />, 
    		dataIndex:"acccur",
    		key:"acccur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.acccur,r2.acccur),
    	},
    	{
    		title:<Label itext="原金额" />, 
    		dataIndex:"accamt",
    		key:"accamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.accamt,r2.accamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"actflg",
    		key:"actflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.actflg,r2.actflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fmtamt",
    		key:"fmtamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fmtamt,r2.fmtamt),
    	},
    ]


    //按钮事件
    onA2bp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/a2bp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onInsbnk_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/insbnk_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_ast= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/setmod_ast',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_recal= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/setmod_recal',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAdvp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/advp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPed= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/ped',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts4_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/pts4_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts2_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/pts2_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts5_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/pts5_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/pts_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts6_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/pts6_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts3_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/pts3_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts1_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/pts1_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onExi= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/exi',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onGlemod_rebook= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/glemod_rebook',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPreper_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/preper_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAvbp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/avbp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAplp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/aplp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onDrwp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/drwp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onCharia_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/charia_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onChk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/chk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts7_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/pts7_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts8_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/pts8_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSav= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/sav',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onInip_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/inip_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLcrdoc_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/lcrdoc_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAdlcnd_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/adlcnd_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onBenp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/benp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onGetref= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/getref',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_feedet= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/setmod_feedet',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_butshw= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/trndoc_butshw',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onRmbp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/rmbp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_reldoc= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/trndoc_reldoc',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onCmbp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/cmbp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLcrgod_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litadd/lcrgod_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div className="transPage">
	<Button  type="primary"  onClick={this.onGetref} desp="Get Ref." path="/mtabut/getref">
		<Label   itext="获取"/>
	</Button>

	
	<Label itext="Reference" trn="litadd" />	
	<InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Reference" path="/lidgrp/rec/ownref" />

	
	<Label itext="Name" trn="litadd" />	
	<InputItem InputProps={bind("nam")}  maxLength={140}  desp="Externally Displayed Name to Identify the Contract" path="/lidgrp/rec/nam" />

	
	<Label itext="Applicant              Ref." trn="litadd" />	
	<InputItem InputProps={bind("pts2_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/apl/pts/ref" />

	
	<Label itext="Form of L/C" trn="litadd" />	
	<SelectItem InputProps={bind("lcrtyp")} code={CodeTable.lcrtyp}  desp="Form of Documentary Credit" path="/lidgrp/rec/lcrtyp"/>
	<InputItem InputProps={bind("pts2_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/apl/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onAplp_sel} desp="查询" path="/litp/aplp/sel">
		<Label   itext="查询"/>
	</Button>

	
	<Label itext="Nominal Amount" trn="litadd" />	
	<InputItem InputProps={bind("usr_nam")}  maxLength={8}  desp="用户ID" path="/litp//sysmod/usr/nam" />
	<CheckboxItem InputProps={bind("resflg")}  desp="Reserved Contract" path="/lidgrp/rec/resflg" />
	<TextAreaItem InputProps={bind("pts2_adrblk")} desp="SWIFT地址" path="/lidgrp/apl/pts/adrblk"/>

	
	<Label itext="Amount Tolerance +/-" trn="litadd" />	
	<SelectItem InputProps={bind("nom1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/lidgrp/cbs/nom1/cur"/>
	<InputItem InputProps={bind("nom1_amt")}   desp="Balance" path="/lidgrp/cbs/nom1/amt" />
	<CheckboxItem InputProps={bind("aammod_addamtflg")}  desp="Add. Amount" path="/litp/aamp/aammod/addamtflg" />

	
	<Label itext="Amount Specification" trn="litadd" />	
	<InputItem InputProps={bind("nomtop")}   desp="Amount Tolerance - Positive" path="/lidgrp/rec/nomtop" />
	<InputItem InputProps={bind("nomton")}   desp="Amount Tolerance - Negative" path="/lidgrp/rec/nomton" />

	
	<Label itext="Maximum Amount" trn="litadd" />	
	<SelectItem InputProps={bind("nomspc")} code={CodeTable.nomspc}  desp="Amount Specification" path="/lidgrp/rec/nomspc"/>

	
	<Label itext="L/C Issued on" trn="litadd" />	
	<SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/lidgrp/cbs/max/cur"/>
	<InputItem InputProps={bind("max_amt")}   desp="Balance" path="/lidgrp/cbs/max/amt" />

	
	<Label itext="Advising Bank     Ref." trn="litadd" />	
	<InputItem InputProps={bind("pts1_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/adv/pts/ref" />

	
	<Label itext="Date Pre-advised" trn="litadd" />	
	<DatePickerItem InputProps={bind("opndat")}  desp="Date L/C Opened/Issued" path="/lidgrp/rec/opndat" />
	<InputItem InputProps={bind("pts1_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/adv/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onAdvp_sel} desp="查询" path="/litp/advp/sel">
		<Label   itext="查询"/>
	</Button>

	
	<Label itext="Latest Shipment Date" trn="litadd" />	
	<DatePickerItem InputProps={bind("preadvdt")}  desp="Date Pre-advised" path="/lidgrp/rec/preadvdt" />
	<TextAreaItem InputProps={bind("pts1_adrblk")} desp="SWIFT地址" path="/lidgrp/adv/pts/adrblk"/>

	
	<Label itext="L/C Expiring on" trn="litadd" />	
	<DatePickerItem InputProps={bind("shpdat")}  desp="Shipment Date" path="/lidgrp/rec/shpdat" />

	
	<Label itext="in (Place)/ counters of" trn="litadd" />	
	<DatePickerItem InputProps={bind("expdat")}  desp="Date of Expiry" path="/lidgrp/rec/expdat" />

	
	<Label itext="Partial Shipment" trn="litadd" />	
	<InputItem InputProps={bind("expplc")}  maxLength={29}  desp="Place of Expiry" path="/lidgrp/rec/expplc" />

	
	<Label itext="Beneficiary           Ref." trn="litadd" />	
	<InputItem InputProps={bind("pts4_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/ben/pts/ref" />

	
	<Label itext="Confirm. Instructions" trn="litadd" />	
	<SelectItem InputProps={bind("shppar")} code={CodeTable.shppar}  desp="Partial Shipment" path="/lidgrp/rec/shppar"/>
	<InputItem InputProps={bind("pts4_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/ben/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onBenp_sel} desp="查询" path="/litp/benp/sel">
		<Label   itext="查询"/>
	</Button>

	
	<Label itext="Transshipment" trn="litadd" />	
	<SelectItem InputProps={bind("shptrs")} code={CodeTable.shppar}  desp="Transshipment" path="/lidgrp/rec/shptrs"/>
	<TextAreaItem InputProps={bind("pts4_adrblk")} desp="SWIFT地址" path="/lidgrp/ben/pts/adrblk"/>

	
	<Label itext="Responsible User" trn="litadd" />	
	<SelectItem InputProps={bind("apprul")} code={CodeTable.apprul}  desp="Applicable Rules" path="/lidgrp/rec/apprul"/>

	
	<Label itext="Applicable Rules" trn="litadd" />	
	<InputItem InputProps={bind("apprultxt")}  maxLength={35}  desp="Other Applicable Rules" path="/lidgrp/rec/apprultxt" />

	
	<Label itext="Other Applicable Rules" trn="litadd" />	
	<SelectItem InputProps={bind("cnfdet")} code={CodeTable.cnfflg}  desp="Confirmation Instructions" path="/lidgrp/rec/cnfdet"/>
	<CheckboxItem InputProps={bind("rmbflg")}  desp="Reimbursement Information" path="/lidgrp/rec/rmbflg" />
	<CheckboxItem InputProps={bind("revflg")}  desp="Revolving Flag" path="/lidgrp/rec/revflg" />

	
	<Label itext="Available with" trn="litadd" />	
	<SelectItem InputProps={bind("avbwth")} code={CodeTable.avbwth}  desp="Available with" path="/lidgrp/rec/avbwth"/>

	
	<Label itext="Presentation Period" trn="litadd" />	
	<CheckboxItem InputProps={bind("blk_preperflg")}  desp="Presentation Period modified" path="/lidgrp/blk/preperflg" />
	<InputItem InputProps={bind("pts3_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/avb/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onAvbp_sel} desp="查询" path="/litp/avbp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("blk_preper")} desp="Presentation Period" path="/lidgrp/blk/preper"/>
	<Button  type="primary" icon="search" onClick={this.onPreper_buttxmsel} desp="..." path="/litp/preper/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<TextAreaItem InputProps={bind("pts3_adrblk")} desp="SWIFT地址" path="/lidgrp/avb/pts/adrblk"/>

	
	<Label itext="Available by" trn="litadd" />	
	<SelectItem InputProps={bind("avbby")} code={CodeTable.avbby0}  desp="Available by" path="/lidgrp/rec/avbby"/>

	
	<Label itext="Details" trn="litadd" />	
	<TextAreaItem InputProps={bind("blk_defdet")} desp="Deferred Payment Details" path="/lidgrp/blk/defdet"/>

	
	<Label itext="Details of Charges" trn="litadd" />	
	<TextAreaItem InputProps={bind("blk_feetxt")} desp="Additional Details to Code for Charges" path="/lidgrp/blk/feetxt"/>
	<Button  type="primary" icon="search" onClick={this.onCharia_buttxmsel} desp="..." path="/litp/charia/buttxmsel">
		<Label   itext="..."/>
	</Button>

	
	<Label itext="Drafts at" trn="litadd" />	
	<TextAreaItem InputProps={bind("blk_dftat")} desp="Drafts at" path="/lidgrp/blk/dftat"/>

	
	<Label itext="Drawee" trn="litadd" />	
	<InputItem InputProps={bind("pts6_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/drw/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onDrwp_sel} desp="查询" path="/litp/drwp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts6_adrblk")} desp="SWIFT地址" path="/lidgrp/drw/pts/adrblk"/>
	<SelectItem InputProps={bind("chato")}   desp="Own Charges Borne by" path="/lidgrp/rec/chato"/>

	
	<Label itext="Deferred Payment" trn="litadd" />	

	
	<Label itext="Country Code" trn="litadd" />	
	<SelectItem InputProps={bind("stacty")}   desp="Country Code Risk Country" path="/lidgrp/rec/stacty"/>

	
	<Label itext="Dispatch from" trn="litadd" />	
	<InputItem InputProps={bind("shpfro")}  maxLength={65}  desp="Shipment from" path="/lidgrp/rec/shpfro" />

	
	<Label itext="Tenor day" trn="litadd" />	
	<InputItem InputProps={bind("tenmaxday")}   desp="Maximum tenor in days" path="/lidgrp/rec/tenmaxday" />

	
	<Label itext="Mixed Payment Details" trn="litadd" />	

	
	<Label itext="Air-/Port of Departure" trn="litadd" />	
	<InputItem InputProps={bind("porloa")}  maxLength={65}  desp="Port of Loading" path="/lidgrp/rec/porloa" />
	<TextAreaItem InputProps={bind("blk_mixdet")} desp="Mixed Payment Details" path="/lidgrp/blk/mixdet"/>

	
	<Label itext="Air-/Port of Destination" trn="litadd" />	
	<InputItem InputProps={bind("pordis")}  maxLength={65}  desp="Port of Discharge" path="/lidgrp/rec/pordis" />

	
	<Label itext="Final Destination" trn="litadd" />	
	<InputItem InputProps={bind("shpto")}  maxLength={65}  desp="For Transportation to" path="/lidgrp/rec/shpto" />

	
	<Label itext="Shipment Period" trn="litadd" />	
	<TextAreaItem InputProps={bind("blk_shpper")} desp="Shipment Period" path="/lidgrp/blk/shpper"/>

	
	<Label itext="2nd Advising Bank" trn="litadd" />	

	
	<Label itext="Ref." trn="litadd" />	
	<InputItem InputProps={bind("pts_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/a2b/pts/ref" />

	
	<Label itext="Applicant's Bank" trn="litadd" />	

	
	<Label itext="Ref." trn="litadd" />	
	<InputItem InputProps={bind("pts7_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/ini/pts/ref" />
	<InputItem InputProps={bind("pts_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/a2b/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onA2bp_sel} desp="查询" path="/litp/a2bp/sel">
		<Label   itext="查询"/>
	</Button>
	<InputItem InputProps={bind("pts7_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/ini/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onInip_sel} desp="查询" path="/litp/inip/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts_adrblk")} desp="SWIFT地址" path="/lidgrp/a2b/pts/adrblk"/>
	<TextAreaItem InputProps={bind("pts7_adrblk")} desp="SWIFT地址" path="/lidgrp/ini/pts/adrblk"/>

	
	<Label itext="Reimbursement Bank" trn="litadd" />	

	
	<Label itext="Ref." trn="litadd" />	
	<InputItem InputProps={bind("pts8_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/rmb/pts/ref" />
	<Label value={this.model.litp_avblab}   desp="Label Available with Bank" path="/litp/avblab" />
	<InputItem InputProps={bind("pts3_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/avb/pts/ref" />

	
	<Label itext="Confirming Bank" trn="litadd" />	
	<InputItem InputProps={bind("pts8_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/rmb/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onRmbp_sel} desp="查询" path="/litp/rmbp/sel">
		<Label   itext="查询"/>
	</Button>
	<InputItem InputProps={bind("pts5_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/cmb/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onCmbp_sel} desp="查询" path="/litp/cmbp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts8_adrblk")} desp="SWIFT地址" path="/lidgrp/rmb/pts/adrblk"/>
	<TextAreaItem InputProps={bind("pts5_adrblk")} desp="SWIFT地址" path="/lidgrp/cmb/pts/adrblk"/>

	
	<Label itext="Description. of Goods" trn="litadd" />	
	<TextAreaItem InputProps={bind("blk_lcrgod")} desp="Description of Gods" path="/lidgrp/blk/lcrgod"/>
	<Button  type="primary" icon="search" onClick={this.onLcrgod_buttxmsel} desp="..." path="/litp/lcrgod/buttxmsel">
		<Label   itext="..."/>
	</Button>

	
	<Label itext="Goods Code " trn="litadd" />	
	<SelectItem InputProps={bind("stagod")}   desp="Goods Code" path="/lidgrp/rec/stagod"/>

	
	<Label itext="Documents Required" trn="litadd" />	
	<TextAreaItem InputProps={bind("blk_lcrdoc")} desp="Documents Required" path="/lidgrp/blk/lcrdoc"/>
	<Button  type="primary" icon="search" onClick={this.onLcrdoc_buttxmsel} desp="..." path="/litp/lcrdoc/buttxmsel">
		<Label   itext="..."/>
	</Button>

	
	<Label itext="Additional Conditions" trn="litadd" />	
	<TextAreaItem InputProps={bind("blk_adlcnd")} desp="Additional Conditions" path="/lidgrp/blk/adlcnd"/>
	<Button  type="primary" icon="search" onClick={this.onAdlcnd_buttxmsel} desp="..." path="/litp/adlcnd/buttxmsel">
		<Label   itext="..."/>
	</Button>

	
	<Label itext="Instructions to Pay.," trn="litadd" />	
	<CheckboxItem InputProps={bind("redclsflg")}  desp="Red/Green Clause" path="/lidgrp/rec/redclsflg" />
	<TextAreaItem InputProps={bind("blk_insbnk")} desp="Instructions to Paying/Accepting/Negotiating Bank" path="/lidgrp/blk/insbnk"/>
	<Button  type="primary" icon="search" onClick={this.onInsbnk_buttxmsel} desp="..." path="/litp/insbnk/buttxmsel">
		<Label   itext="..."/>
	</Button>

	
	<Label itext="Accept., Negot. Bank" trn="litadd" />	

	
	<Label itext="结算金额" trn="litadd" />	
	<SelectItem InputProps={bind("setmod_doccur")} code={CodeTable.curtxt}  desp="document currency" path="/setmod/doccur"/>
	<InputItem InputProps={bind("setmod_docamt")}   desp="document amount" path="/setmod/docamt" />
	<Button  type="primary"  onClick={this.onSetmod_feedet} desp="重算金额" path="/setmod/feedet">
		<Label   itext="重算金额"/>
	</Button>
	<Button  type="primary"  onClick={this.onSetmod_ast} desp="加载账务" path="/setmod/ast">
		<Label   itext="加载账务"/>
	</Button>

	
	<Label itext="FEEMAC" trn="litadd" />	
	<InputItem InputProps={bind("setmod_feemac")}  maxLength={200}  desp="FEEMAC" path="/setmod/feemac" />
	<Button  type="primary"  onClick={this.onSetmod_recal} desp="重算账务" path="/setmod/recal">
		<Label   itext="重算账务"/>
	</Button>

	
	<Label itext="费用明细" trn="litadd" />	

	
	<Label itext="SETMAC" trn="litadd" />	
	<InputItem InputProps={bind("setmod_setmac")}  maxLength={200}  desp="SETMAC" path="/setmod/setmac" />
	<Table rowKey="inr" columns={this.fegmod_feslstHeader}  dataSource={this.model.fegmod_feslst}   path="/setmod/setfeg/fegmod/feslst"/>

	
	<Label itext="账务明细" trn="litadd" />	
	<Table rowKey="inr" columns={this.glgmod_glslstHeader}  dataSource={this.model.glgmod_glslst}   path="/setmod/setglg/glgmod/glslst"/>

	
	<Label itext="会计分录" trn="litadd" />	
	<Button  type="primary"  onClick={this.onGlemod_rebook} desp="分录加载" path="/setmod/glemod/rebook">
		<Label   itext="分录加载"/>
	</Button>
	<Table rowKey="inr" columns={this.glemod_glelstHeader}  dataSource={this.model.glemod_glelst}   path="/setmod/glemod/glelst"/>

	
	<Label itext="面函码值" trn="litadd" />	
	<InputItem InputProps={bind("trndoc_doccod")}  maxLength={16}  desp="面函码值" path="/trnmod/trndoc/doccod" />

	
	<Label itext="Per Medium" trn="litadd" />	
	<InputItem InputProps={bind("trndoc_cortyp")}  maxLength={3}  desp="Per Medium" path="/trnmod/trndoc/cortyp" />
	<Button  type="primary"  onClick={this.onTrndoc_reldoc} desp="面函加载" path="/trnmod/trndoc/reldoc">
		<Label   itext="面函加载"/>
	</Button>
	<Button  type="primary"  onClick={this.onTrndoc_butshw} desp="show doc." path="/trnmod/trndoc/butshw">
		<Label   itext="展示"/>
	</Button>

	
	<Label itext="面函路径" trn="litadd" />	
	<InputItem InputProps={bind("trndoc_docpth")}  maxLength={100}  desp="面函路径" path="/trnmod/trndoc/docpth" />
	<Table rowKey="inr" columns={this.docmod_doclstHeader}  dataSource={this.model.docmod_doclst}   path="/trnmod/trndoc/docmod/doclst"/>

	
	<Label itext="唯一编号" trn="litadd" />	
	<InputItem InputProps={bind("spt_inr")}  maxLength={8}  desp="唯一编号" path="/sysmod/spt/inr" />

	
	<Label itext="A" trn="litadd" />	
	<InputItem InputProps={bind("trndoc_doctrestm")}   desp="Document tree" path="/trnmod/trndoc/doctrestm" />
	<Button  type="primary"  onClick={this.onTrndoc_butadd} desp="Details" path="/trnmod/trndoc/butadd">
		<Label   itext="B"/>
	</Button>
	<Button  type="primary"  onClick={this.onTrndoc_butnew} desp="New Entry" path="/trnmod/trndoc/butnew">
		<Label   itext="C"/>
	</Button>
	<Button  icon="delete" onClick={this.onTrndoc_butdel} desp="Delete Entry" path="/trnmod/trndoc/butdel">
		<Label   itext="D"/>
	</Button>
	<CheckboxItem InputProps={bind("trndoc_shwinc")}  desp="Show Incoming Messages" path="/trnmod/trndoc/shwinc" />
	<CheckboxItem InputProps={bind("trndoc_shwout")}  desp="Show Outgoing Messages" path="/trnmod/trndoc/shwout" />
	<CheckboxItem InputProps={bind("trndoc_shwoutint")}  desp="Show Internal Messages" path="/trnmod/trndoc/shwoutint" />
	<Button  type="primary"  onClick={this.onTrndoc_butatt} desp="Attach" path="/trnmod/trndoc/butatt">
		<Label   itext="E"/>
	</Button>
	<InputItem InputProps={bind("trndoc_condocstm")}   desp="Connected Documents" path="/trnmod/trndoc/condocstm" />
	<Button  type="primary" icon="save"
		  onClick={this.onSav} desp="Save" path="/mtabut/sav">
		<Label   itext="提交"/>
	</Button>
	<Button  type="primary"  onClick={this.onChk} desp="Check" path="/mtabut/chk">
		<Label   itext="检核"/>
	</Button>
	<Button  type="primary"  onClick={this.onPed} desp="暂存" path="/mtabut/ped">
		<Label   itext="暂存"/>
	</Button>
	<Button  type="primary"  onClick={this.onExi} desp="Exit" path="/mtabut/exi">
		<Label   itext="退出"/>
	</Button>
		</div>
		)
	}
}
