import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table} from '@/components/Common-Library'
import Api from '@/service/api'
import mLitatt from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class LitattScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'litatt'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mLitatt()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('litatt/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }



    //按钮事件
    onSav= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litatt/sav',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPed= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litatt/ped',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onChk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litatt/chk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onExi= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litatt/exi',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div className="transPage">

	
	<Label itext="参考号" trn="litatt" />	
	<InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Reference" path="/lidgrp/rec/ownref" />

	
	<Label itext="名称" trn="litatt" />	
	<InputItem InputProps={bind("nam")}  maxLength={140}  desp="Externally Displayed Name to Identify the Contract" path="/lidgrp/rec/nam" />

	
	<Label itext="开证金额" trn="litatt" />	
	<SelectItem InputProps={bind("nom1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/lidgrp/cbs/nom1/cur"/>
	<InputItem InputProps={bind("nom1_amt")}   desp="Balance" path="/lidgrp/cbs/nom1/amt" />

	
	<Label itext="申请人                     参考号" trn="litatt" />	
	<InputItem InputProps={bind("pts1_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/apl/pts/ref" />
	<CheckboxItem InputProps={bind("aammod_addamtflg")}  desp="Add. Amount" path="/litp0/aammod/addamtflg" />

	
	<Label itext="信用证余额" trn="litatt" />	
	<InputItem InputProps={bind("opn1_cur")}  maxLength={3}  desp="Currency" path="/lidgrp/cbs/opn1/cur" />
	<InputItem InputProps={bind("opn1_amt")}   desp="Balance" path="/lidgrp/cbs/opn1/amt" />
	<CheckboxItem InputProps={bind("revflg")}  desp="Revolving Flag" path="/lidgrp/rec/revflg" />
	<InputItem InputProps={bind("pts1_nam")}  maxLength={100}  desp="客户英文名称" path="/lidgrp/apl/pts/nam" />

	
	<Label itext="指定银行" trn="litatt" />	
	<InputItem InputProps={bind("lidgrp_avbnam")}  maxLength={40}  desp="Available with Bank" path="/lidgrp/avbnam" />

	
	<Label itext="受益人" trn="litatt" />	

	
	<Label itext="参考号" trn="litatt" />	
	<InputItem InputProps={bind("pts2_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/ben/pts/ref" />
	<CheckboxItem InputProps={bind("redclsflg")}  desp="Red/Green Clause" path="/lidgrp/rec/redclsflg" />

	
	<Label itext="兑付方式" trn="litatt" />	
	<SelectItem InputProps={bind("avbby")}   desp="Available by" path="/lidgrp/rec/avbby"/>
	<InputItem InputProps={bind("pts2_nam")}  maxLength={100}  desp="客户英文名称" path="/lidgrp/ben/pts/nam" />

	
	<Label itext="开立日期" trn="litatt" />	
	<DatePickerItem InputProps={bind("opndat")}  desp="Date L/C Opened/Issued" path="/lidgrp/rec/opndat" />

	
	<Label itext="Shipment Date" trn="litatt" />	
	<DatePickerItem InputProps={bind("shpdat")}  desp="Shipment Date" path="/lidgrp/rec/shpdat" />

	
	<Label itext="通知行" trn="litatt" />	

	
	<Label itext="参考号" trn="litatt" />	
	<InputItem InputProps={bind("pts_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/adv/pts/ref" />

	
	<Label itext="到期日" trn="litatt" />	
	<DatePickerItem InputProps={bind("expdat")}  desp="Date of Expiry" path="/lidgrp/rec/expdat" />
	<InputItem InputProps={bind("expplc")}  maxLength={29}  desp="Place of Expiry" path="/lidgrp/rec/expplc" />
	<InputItem InputProps={bind("pts_nam")}  maxLength={100}  desp="客户英文名称" path="/lidgrp/adv/pts/nam" />

	
	<Label itext="信用证类型" trn="litatt" />	
	<SelectItem InputProps={bind("lcrtyp")}   desp="Form of Documentary Credit" path="/lidgrp/rec/lcrtyp"/>
	<Button  type="primary" icon="save"
		  onClick={this.onSav} desp="Save" path="/mtabut/sav">
		<Label   itext="提交"/>
	</Button>
	<Button  type="primary"  onClick={this.onChk} desp="Check" path="/mtabut/chk">
		<Label   itext="检核"/>
	</Button>
	<Button  type="primary"  onClick={this.onPed} desp="暂存" path="/mtabut/ped">
		<Label   itext="暂存"/>
	</Button>
	<Button  type="primary"  onClick={this.onExi} desp="Exit" path="/mtabut/exi">
		<Label   itext="退出"/>
	</Button>
		</div>
		)
	}
}
