import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table} from '@/components/Common-Library'
import Api from '@/service/api'
import mLitcan from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class LitcanScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'litcan'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mLitcan()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('litcan/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }

    glemod_glelstHeader=[
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"dbtcdt",
    		key:"dbtcdt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dbtcdt,r2.dbtcdt),
    	},
    	{
    		title:<Label itext="账号" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="起息日" />, 
    		dataIndex:"valdat",
    		key:"valdat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.valdat,r2.valdat),
    	},
    	{
    		title:<Label itext="科目号" />, 
    		dataIndex:"trmtyp",
    		key:"trmtyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.trmtyp,r2.trmtyp),
    	},
    	{
    		title:<Label itext="PN序号" />, 
    		dataIndex:"prn",
    		key:"prn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.prn,r2.prn),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rat",
    		key:"rat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rat,r2.rat),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fctsgn",
    		key:"fctsgn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fctsgn,r2.fctsgn),
    	},
    ]
    glgmod_glslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"debcdtflg",
    		key:"debcdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.debcdtflg,r2.debcdtflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.debcdtflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="结算方式" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp2.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="账户" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="原币种" />, 
    		dataIndex:"acccur",
    		key:"acccur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.acccur,r2.acccur),
    	},
    	{
    		title:<Label itext="原金额" />, 
    		dataIndex:"accamt",
    		key:"accamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.accamt,r2.accamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"actflg",
    		key:"actflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.actflg,r2.actflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fmtamt",
    		key:"fmtamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fmtamt,r2.fmtamt),
    	},
    ]
    liaccv_liaccvgHeader=[
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="原始金额" />, 
    		dataIndex:"oldamt",
    		key:"oldamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.oldamt,r2.oldamt),
    	},
    	{
    		title:<Label itext="变动金额" />, 
    		dataIndex:"chgamt",
    		key:"chgamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.chgamt,r2.chgamt),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="结算账号" />, 
    		dataIndex:"cusact",
    		key:"cusact",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cusact,r2.cusact),
    	},
    	{
    		title:<Label itext="保证金账号" />, 
    		dataIndex:"ccvact",
    		key:"ccvact",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.ccvact,r2.ccvact),
    	},
    	{
    		title:<Label itext="记账" />, 
    		dataIndex:"gleflg",
    		key:"gleflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.gleflg,r2.gleflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.onsel.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    ]
    docmod_doclstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"role",
    		key:"role",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.role,r2.role),
    	},
    	{
    		title:<Label itext="码值" />, 
    		dataIndex:"id",
    		key:"id",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.id,r2.id),
    	},
    	{
    		title:<Label itext="凭证名称" />, 
    		dataIndex:"docnam",
    		key:"docnam",
    		width:200,
    		sorter: (r1,r2)=>ColSorter(r1.docnam,r2.docnam),
    	},
    	{
    		title:<Label itext="凭证类型" />, 
    		dataIndex:"cortyp",
    		key:"cortyp",
    		width:150,
    		sorter: (r1,r2)=>ColSorter(r1.cortyp,r2.cortyp),
    	},
    	{
    		title:<Label itext="出具/发送" />, 
    		dataIndex:"mdtflg",
    		key:"mdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.mdtflg,r2.mdtflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"ptainr",
    		key:"ptainr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.ptainr,r2.ptainr),
    	},
    ]
    fegmod_feslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="费用代码" />, 
    		dataIndex:"feecod",
    		key:"feecod",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feecod,r2.feecod),
    	},
    	{
    		title:<Label itext="费用名称" />, 
    		dataIndex:"feetxt",
    		key:"feetxt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feetxt,r2.feetxt),
    	},
    	{
    		title:<Label itext="收费币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="应收金额" />, 
    		dataIndex:"basamt",
    		key:"basamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.basamt,r2.basamt),
    	},
    	{
    		title:<Label itext="实收金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="现收/缓收" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="内扣/外收" />, 
    		dataIndex:"payflg",
    		key:"payflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.payflg,r2.payflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.payflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfcur",
    		key:"xrfcur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfcur,r2.xrfcur),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfamt",
    		key:"xrfamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfamt,r2.xrfamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"feeacc",
    		key:"feeacc",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feeacc,r2.feeacc),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fepinr",
    		key:"fepinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fepinr,r2.fepinr),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rolptyinr",
    		key:"rolptyinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rolptyinr,r2.rolptyinr),
    	},
    ]
    liaall_liaallgHeader=[
    	{
    		title:<Label itext="业务种类" />, 
    		dataIndex:"bussec",
    		key:"bussec",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.bussec,r2.bussec),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.bussec.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="表外类型" />, 
    		dataIndex:"liatyp",
    		key:"liatyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.liatyp,r2.liatyp),
    	},
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="原金额" />, 
    		dataIndex:"oldamt",
    		key:"oldamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.oldamt,r2.oldamt),
    	},
    	{
    		title:<Label itext="变动金额" />, 
    		dataIndex:"chgamt",
    		key:"chgamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.chgamt,r2.chgamt),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="表外账号" />, 
    		dataIndex:"acc",
    		key:"acc",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.acc,r2.acc),
    	},
    ]


    //按钮事件
    onSetmod_ast= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litcan/setmod_ast',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onChk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litcan/chk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSav= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litcan/sav',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_recal= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litcan/setmod_recal',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLiaccv_recalccv= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litcan/liaccv_recalccv',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPed= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litcan/ped',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onExi= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litcan/exi',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLiaall_astlia= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litcan/liaall_astlia',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onGlemod_rebook= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litcan/glemod_rebook',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_feedet= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litcan/setmod_feedet',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_butshw= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litcan/trndoc_butshw',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_reldoc= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litcan/trndoc_reldoc',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div className="transPage">

	
	<Label itext="参考号" trn="litcan" />	
	<InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Reference" path="/lidgrp/rec/ownref" />

	
	<Label itext="名称" trn="litcan" />	
	<InputItem InputProps={bind("nam")}  maxLength={140}  desp="Externally Displayed Name to Identify the Contract" path="/lidgrp/rec/nam" />

	
	<Label itext="开证金额" trn="litcan" />	
	<SelectItem InputProps={bind("nom1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/lidgrp/cbs/nom1/cur"/>
	<InputItem InputProps={bind("nom1_amt")}   desp="Balance" path="/lidgrp/cbs/nom1/amt" />

	
	<Label itext="申请人                     参考号" trn="litcan" />	
	<InputItem InputProps={bind("pts1_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/apl/pts/ref" />
	<CheckboxItem InputProps={bind("aammod_addamtflg")}  desp="Add. Amount" path="/litp0/aammod/addamtflg" />

	
	<Label itext="信用证余额" trn="litcan" />	
	<InputItem InputProps={bind("opn1_cur")}  maxLength={3}  desp="Currency" path="/lidgrp/cbs/opn1/cur" />
	<InputItem InputProps={bind("opn1_amt")}   desp="Balance" path="/lidgrp/cbs/opn1/amt" />
	<CheckboxItem InputProps={bind("revflg")}  desp="Revolving Flag" path="/lidgrp/rec/revflg" />
	<InputItem InputProps={bind("pts1_nam")}  maxLength={100}  desp="客户英文名称" path="/lidgrp/apl/pts/nam" />

	
	<Label itext="指定银行" trn="litcan" />	
	<InputItem InputProps={bind("lidgrp_avbnam")}  maxLength={40}  desp="Available with Bank" path="/lidgrp/avbnam" />

	
	<Label itext="受益人" trn="litcan" />	

	
	<Label itext="参考号" trn="litcan" />	
	<InputItem InputProps={bind("pts2_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/ben/pts/ref" />
	<CheckboxItem InputProps={bind("redclsflg")}  desp="Red/Green Clause" path="/lidgrp/rec/redclsflg" />

	
	<Label itext="兑付方式" trn="litcan" />	
	<SelectItem InputProps={bind("avbby")}   desp="Available by" path="/lidgrp/rec/avbby"/>
	<InputItem InputProps={bind("pts2_nam")}  maxLength={100}  desp="客户英文名称" path="/lidgrp/ben/pts/nam" />

	
	<Label itext="开立日期" trn="litcan" />	
	<DatePickerItem InputProps={bind("opndat")}  desp="Date L/C Opened/Issued" path="/lidgrp/rec/opndat" />

	
	<Label itext="Shipment Date" trn="litcan" />	
	<DatePickerItem InputProps={bind("shpdat")}  desp="Shipment Date" path="/lidgrp/rec/shpdat" />

	
	<Label itext="通知行" trn="litcan" />	

	
	<Label itext="参考号" trn="litcan" />	
	<InputItem InputProps={bind("pts_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/adv/pts/ref" />

	
	<Label itext="到期日" trn="litcan" />	
	<DatePickerItem InputProps={bind("expdat")}  desp="Date of Expiry" path="/lidgrp/rec/expdat" />
	<InputItem InputProps={bind("expplc")}  maxLength={29}  desp="Place of Expiry" path="/lidgrp/rec/expplc" />
	<InputItem InputProps={bind("pts_nam")}  maxLength={100}  desp="客户英文名称" path="/lidgrp/adv/pts/nam" />

	
	<Label itext="信用证类型" trn="litcan" />	
	<SelectItem InputProps={bind("lcrtyp")}   desp="Form of Documentary Credit" path="/lidgrp/rec/lcrtyp"/>
	<CheckboxItem InputProps={bind("byinst")}  desp="On Applicant instruction" path="/byinst" />

	
	<Label itext="Narrative" trn="litcan" />	
	<CheckboxItem InputProps={bind("sndmsg")}  desp="Send message to apllicant" path="/sndmsg" />

	
	<Label itext="Narrative" trn="litcan" />	
	<Button  type="primary"  onClick={this.onLiaall_astlia} desp="表外加载" path="/liaall/astlia">
		<Label   itext="表外加载"/>
	</Button>

	
	<Label itext="表外明细" trn="litcan" />	
	<Table rowKey="inr" columns={this.liaall_liaallgHeader}  dataSource={this.model.liaall_liaallg}   path="/liaall/liaallg"/>

	
	<Label itext="保证金明细" trn="litcan" />	
	<SelectItem InputProps={bind("liaccv_concur")} code={CodeTable.curtxt}  desp="业务结算币种" path="/liaall/liaccv/concur"/>

	
	<Label itext="业务余额" trn="litcan" />	
	<InputItem InputProps={bind("liaccv_newamt")}   desp="业务金额" path="/liaall/liaccv/newamt" />

	
	<Label itext="保证金应收比例" trn="litcan" />	
	<InputItem InputProps={bind("liaccv_cshpct")}   desp="保证金应收比例" path="/liaall/liaccv/cshpct" />

	
	<Label itext="%" trn="litcan" />	

	
	<Label itext="变动金额" trn="litcan" />	
	<InputItem InputProps={bind("liaccv_chgamt")}   desp="变动金额" path="/liaall/liaccv/chgamt" />
	<InputItem InputProps={bind("liaccv_relcshpct")}   desp="保证金实收比例" path="/liaall/liaccv/relcshpct" />

	
	<Label itext="保证金实收比例" trn="litcan" />	

	
	<Label itext="%" trn="litcan" />	

	
	<Label itext="应收/支保证金" trn="litcan" />	
	<InputItem InputProps={bind("liaccv_pctresamt")}   desp="应收/支保证金" path="/liaall/liaccv/pctresamt" />
	<Button  type="primary"  onClick={this.onLiaccv_recalccv} desp="汇率重算" path="/liaall/liaccv/recalccv">
		<Label   itext="汇率重算"/>
	</Button>
	<Table rowKey="inr" columns={this.liaccv_liaccvgHeader}  dataSource={this.model.liaccv_liaccvg}   path="/liaall/liaccv/liaccvg"/>

	
	<Label itext="保证金合计" trn="litcan" />	
	<InputItem InputProps={bind("liaccv_totcovamt")}   desp="保证金合计" path="/liaall/liaccv/totcovamt" />

	
	<Label itext="业务余额" trn="litcan" />	

	
	<Label itext="保证金应收比例" trn="litcan" />	

	
	<Label itext="%" trn="litcan" />	

	
	<Label itext="变动金额" trn="litcan" />	

	
	<Label itext="保证金实收比例" trn="litcan" />	

	
	<Label itext="%" trn="litcan" />	

	
	<Label itext="应收/支保证金" trn="litcan" />	

	
	<Label itext="保证金合计" trn="litcan" />	

	
	<Label itext="结算金额" trn="litcan" />	
	<SelectItem InputProps={bind("setmod_doccur")} code={CodeTable.curtxt}  desp="document currency" path="/setmod/doccur"/>
	<InputItem InputProps={bind("setmod_docamt")}   desp="document amount" path="/setmod/docamt" />
	<Button  type="primary"  onClick={this.onSetmod_feedet} desp="重算金额" path="/setmod/feedet">
		<Label   itext="重算金额"/>
	</Button>
	<Button  type="primary"  onClick={this.onSetmod_ast} desp="加载账务" path="/setmod/ast">
		<Label   itext="加载账务"/>
	</Button>

	
	<Label itext="FEEMAC" trn="litcan" />	
	<InputItem InputProps={bind("setmod_feemac")}  maxLength={200}  desp="FEEMAC" path="/setmod/feemac" />
	<Button  type="primary"  onClick={this.onSetmod_recal} desp="重算账务" path="/setmod/recal">
		<Label   itext="重算账务"/>
	</Button>

	
	<Label itext="费用明细" trn="litcan" />	

	
	<Label itext="SETMAC" trn="litcan" />	
	<InputItem InputProps={bind("setmod_setmac")}  maxLength={200}  desp="SETMAC" path="/setmod/setmac" />
	<Table rowKey="inr" columns={this.fegmod_feslstHeader}  dataSource={this.model.fegmod_feslst}   path="/setmod/setfeg/fegmod/feslst"/>

	
	<Label itext="账务明细" trn="litcan" />	
	<Table rowKey="inr" columns={this.glgmod_glslstHeader}  dataSource={this.model.glgmod_glslst}   path="/setmod/setglg/glgmod/glslst"/>

	
	<Label itext="会计分录" trn="litcan" />	
	<Button  type="primary"  onClick={this.onGlemod_rebook} desp="分录加载" path="/setmod/glemod/rebook">
		<Label   itext="分录加载"/>
	</Button>
	<Table rowKey="inr" columns={this.glemod_glelstHeader}  dataSource={this.model.glemod_glelst}   path="/setmod/glemod/glelst"/>

	
	<Label itext="面函码值" trn="litcan" />	
	<InputItem InputProps={bind("trndoc_doccod")}  maxLength={16}  desp="面函码值" path="/trnmod/trndoc/doccod" />

	
	<Label itext="Per Medium" trn="litcan" />	
	<InputItem InputProps={bind("trndoc_cortyp")}  maxLength={3}  desp="Per Medium" path="/trnmod/trndoc/cortyp" />
	<Button  type="primary"  onClick={this.onTrndoc_reldoc} desp="面函加载" path="/trnmod/trndoc/reldoc">
		<Label   itext="面函加载"/>
	</Button>
	<Button  type="primary"  onClick={this.onTrndoc_butshw} desp="show doc." path="/trnmod/trndoc/butshw">
		<Label   itext="展示"/>
	</Button>

	
	<Label itext="面函路径" trn="litcan" />	
	<InputItem InputProps={bind("trndoc_docpth")}  maxLength={100}  desp="面函路径" path="/trnmod/trndoc/docpth" />
	<Table rowKey="inr" columns={this.docmod_doclstHeader}  dataSource={this.model.docmod_doclst}   path="/trnmod/trndoc/docmod/doclst"/>

	
	<Label itext="唯一编号" trn="litcan" />	
	<InputItem InputProps={bind("spt_inr")}  maxLength={8}  desp="唯一编号" path="/sysmod/spt/inr" />
	<Button  type="primary" icon="save"
		  onClick={this.onSav} desp="Save" path="/mtabut/sav">
		<Label   itext="提交"/>
	</Button>
	<Button  type="primary"  onClick={this.onChk} desp="Check" path="/mtabut/chk">
		<Label   itext="检核"/>
	</Button>
	<Button  type="primary"  onClick={this.onPed} desp="暂存" path="/mtabut/ped">
		<Label   itext="暂存"/>
	</Button>
	<Button  type="primary"  onClick={this.onExi} desp="Exit" path="/mtabut/exi">
		<Label   itext="退出"/>
	</Button>
		</div>
		)
	}
}
