import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table} from '@/components/Common-Library'
import Api from '@/service/api'
import mLitdla from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class LitdlaScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'litdla'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mLitdla()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('litdla/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }

    glemod_glelstHeader=[
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"dbtcdt",
    		key:"dbtcdt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dbtcdt,r2.dbtcdt),
    	},
    	{
    		title:<Label itext="账号" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="起息日" />, 
    		dataIndex:"valdat",
    		key:"valdat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.valdat,r2.valdat),
    	},
    	{
    		title:<Label itext="科目号" />, 
    		dataIndex:"trmtyp",
    		key:"trmtyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.trmtyp,r2.trmtyp),
    	},
    	{
    		title:<Label itext="PN序号" />, 
    		dataIndex:"prn",
    		key:"prn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.prn,r2.prn),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rat",
    		key:"rat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rat,r2.rat),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fctsgn",
    		key:"fctsgn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fctsgn,r2.fctsgn),
    	},
    ]
    glgmod_glslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"debcdtflg",
    		key:"debcdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.debcdtflg,r2.debcdtflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.debcdtflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="结算方式" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp2.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="账户" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="原币种" />, 
    		dataIndex:"acccur",
    		key:"acccur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.acccur,r2.acccur),
    	},
    	{
    		title:<Label itext="原金额" />, 
    		dataIndex:"accamt",
    		key:"accamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.accamt,r2.accamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"actflg",
    		key:"actflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.actflg,r2.actflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fmtamt",
    		key:"fmtamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fmtamt,r2.fmtamt),
    	},
    ]
    liaccv_liaccvgHeader=[
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="原始金额" />, 
    		dataIndex:"oldamt",
    		key:"oldamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.oldamt,r2.oldamt),
    	},
    	{
    		title:<Label itext="变动金额" />, 
    		dataIndex:"chgamt",
    		key:"chgamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.chgamt,r2.chgamt),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="结算账号" />, 
    		dataIndex:"cusact",
    		key:"cusact",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cusact,r2.cusact),
    	},
    	{
    		title:<Label itext="保证金账号" />, 
    		dataIndex:"ccvact",
    		key:"ccvact",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.ccvact,r2.ccvact),
    	},
    	{
    		title:<Label itext="记账" />, 
    		dataIndex:"gleflg",
    		key:"gleflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.gleflg,r2.gleflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.onsel.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    ]
    docmod_doclstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"role",
    		key:"role",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.role,r2.role),
    	},
    	{
    		title:<Label itext="码值" />, 
    		dataIndex:"id",
    		key:"id",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.id,r2.id),
    	},
    	{
    		title:<Label itext="凭证名称" />, 
    		dataIndex:"docnam",
    		key:"docnam",
    		width:200,
    		sorter: (r1,r2)=>ColSorter(r1.docnam,r2.docnam),
    	},
    	{
    		title:<Label itext="凭证类型" />, 
    		dataIndex:"cortyp",
    		key:"cortyp",
    		width:150,
    		sorter: (r1,r2)=>ColSorter(r1.cortyp,r2.cortyp),
    	},
    	{
    		title:<Label itext="出具/发送" />, 
    		dataIndex:"mdtflg",
    		key:"mdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.mdtflg,r2.mdtflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"ptainr",
    		key:"ptainr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.ptainr,r2.ptainr),
    	},
    ]
    fegmod_feslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="费用代码" />, 
    		dataIndex:"feecod",
    		key:"feecod",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feecod,r2.feecod),
    	},
    	{
    		title:<Label itext="费用名称" />, 
    		dataIndex:"feetxt",
    		key:"feetxt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feetxt,r2.feetxt),
    	},
    	{
    		title:<Label itext="收费币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="应收金额" />, 
    		dataIndex:"basamt",
    		key:"basamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.basamt,r2.basamt),
    	},
    	{
    		title:<Label itext="实收金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="现收/缓收" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="内扣/外收" />, 
    		dataIndex:"payflg",
    		key:"payflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.payflg,r2.payflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.payflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfcur",
    		key:"xrfcur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfcur,r2.xrfcur),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfamt",
    		key:"xrfamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfamt,r2.xrfamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"feeacc",
    		key:"feeacc",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feeacc,r2.feeacc),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fepinr",
    		key:"fepinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fepinr,r2.fepinr),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rolptyinr",
    		key:"rolptyinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rolptyinr,r2.rolptyinr),
    	},
    ]
    liaall_liaallgHeader=[
    	{
    		title:<Label itext="业务种类" />, 
    		dataIndex:"bussec",
    		key:"bussec",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.bussec,r2.bussec),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.bussec.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="表外类型" />, 
    		dataIndex:"liatyp",
    		key:"liatyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.liatyp,r2.liatyp),
    	},
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="原金额" />, 
    		dataIndex:"oldamt",
    		key:"oldamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.oldamt,r2.oldamt),
    	},
    	{
    		title:<Label itext="变动金额" />, 
    		dataIndex:"chgamt",
    		key:"chgamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.chgamt,r2.chgamt),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="表外账号" />, 
    		dataIndex:"acc",
    		key:"acc",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.acc,r2.acc),
    	},
    ]


    //按钮事件
    onA2bp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/a2bp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAdlcndame_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/adlcndame_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_ast= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/setmod_ast',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_recal= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/setmod_recal',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAdvp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/advp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPed= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/ped',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts4_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/pts4_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts2_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/pts2_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts5_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/pts5_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/pts_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts6_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/pts6_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts3_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/pts3_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts1_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/pts1_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onExi= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/exi',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLiaall_astlia= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/liaall_astlia',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onGlemod_rebook= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/glemod_rebook',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPreper_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/preper_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAvbp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/avbp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAplp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/aplp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onDrwp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/drwp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onCharia_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/charia_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onChk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/chk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLcrdocame_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/lcrdocame_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts7_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/pts7_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts8_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/pts8_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSav= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/sav',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onInip_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/inip_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLcrdoc_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/lcrdoc_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLiaccv_recalccv= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/liaccv_recalccv',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLcrgodame_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/lcrgodame_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onBenp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/benp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onGetref= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/getref',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_feedet= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/setmod_feedet',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_butshw= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/trndoc_butshw',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onRmbp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/rmbp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_reldoc= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/trndoc_reldoc',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onCmbp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/cmbp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLcrgod_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litdla/lcrgod_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div className="transPage">

	
	<Label itext="参考号" trn="litdla" />	
	<InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Reference" path="/lidgrp/rec/ownref" />

	
	<Label itext="摘要" trn="litdla" />	
	<InputItem InputProps={bind("nam")}  maxLength={140}  desp="Externally Displayed Name to Identify the Contract" path="/lidgrp/rec/nam" />

	
	<Label itext="申请人" trn="litdla" />	
	<InputItem InputProps={bind("pts2_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/apl/pts/ref" />

	
	<Label itext="信用证金额" trn="litdla" />	
	<SelectItem InputProps={bind("nom1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/lidgrp/cbs/nom1/cur"/>
	<InputItem InputProps={bind("nom1_amt")}   desp="Balance" path="/lidgrp/cbs/nom1/amt" />
	<InputItem InputProps={bind("pts2_nam")}  maxLength={100}  desp="客户英文名称" path="/lidgrp/apl/pts/nam" />

	
	<Label itext="信用证余额" trn="litdla" />	
	<SelectItem InputProps={bind("opn1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/lidgrp/cbs/opn1/cur"/>
	<InputItem InputProps={bind("opn1_amt")}   desp="Balance" path="/lidgrp/cbs/opn1/amt" />

	
	<Label itext="指定银行" trn="litdla" />	
	<InputItem InputProps={bind("lidgrp_avbnam")}  maxLength={40}  desp="Available with Bank" path="/lidgrp/avbnam" />

	
	<Label itext="受益人" trn="litdla" />	
	<InputItem InputProps={bind("pts4_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/ben/pts/ref" />
	<InputItem InputProps={bind("pts4_nam")}  maxLength={100}  desp="客户英文名称" path="/lidgrp/ben/pts/nam" />

	
	<Label itext="by" trn="litdla" />	
	<SelectItem InputProps={bind("avbby")}   desp="Available by" path="/lidgrp/rec/avbby"/>

	
	<Label itext="开证日期" trn="litdla" />	
	<DatePickerItem InputProps={bind("opndat")}  desp="Date L/C Opened/Issued" path="/lidgrp/rec/opndat" />

	
	<Label itext="最迟装运日期" trn="litdla" />	
	<DatePickerItem InputProps={bind("shpdat")}  desp="Shipment Date" path="/lidgrp/rec/shpdat" />

	
	<Label itext="通知行" trn="litdla" />	
	<InputItem InputProps={bind("pts1_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/adv/pts/ref" />

	
	<Label itext="到期日/到期地点" trn="litdla" />	
	<DatePickerItem InputProps={bind("expdat")}  desp="Date of Expiry" path="/lidgrp/rec/expdat" />
	<InputItem InputProps={bind("expplc")}  maxLength={29}  desp="Place of Expiry" path="/lidgrp/rec/expplc" />
	<InputItem InputProps={bind("pts1_nam")}  maxLength={100}  desp="客户英文名称" path="/lidgrp/adv/pts/nam" />

	
	<Label itext="信用证类型" trn="litdla" />	
	<SelectItem InputProps={bind("lcrtyp")}   desp="Form of Documentary Credit" path="/lidgrp/rec/lcrtyp"/>

	
	<Label itext="Amount Amend History List:" trn="litdla" />	

	
	<Label itext="次修改（减额）" trn="litdla" />	

	
	<Label itext="参考号" trn="litdla" />	
	<InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Reference" path="/lidgrp/rec/ownref" />

	
	<Label itext="摘要" trn="litdla" />	
	<InputItem InputProps={bind("nam")}  maxLength={140}  desp="Externally Displayed Name to Identify the Contract" path="/lidgrp/rec/nam" />

	
	<Label itext="修改日期" trn="litdla" />	
	<DatePickerItem InputProps={bind("swiadd_amedat")}  desp="Date of Amendment" path="/litamep/swiadd/amedat" />

	
	<Label itext="修改次数" trn="litdla" />	
	<InputItem InputProps={bind("swiadd_amenbr")}   desp="Number of Amendment" path="/litamep/swiadd/amenbr" />

	
	<Label itext="实际修改次数" trn="litdla" />	
	<InputItem InputProps={bind("litamep_amenbr")}   desp="Number of Amendment" path="/litamep/amenbr" />

	
	<Label itext="Nominal Amount" trn="litdla" />	
	<SelectItem InputProps={bind("nom1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/lidgrp/cbs/nom1/cur"/>
	<InputItem InputProps={bind("nom11_amt")}   desp="Balance" path="/oldlidgrp/cbs/nom1/amt" />

	
	<Label itext="溢短装" trn="litdla" />	
	<InputItem InputProps={bind("nomtop1")}   desp="Amount Tolerance - Positive" path="/oldlidgrp/rec/nomtop" />
	<InputItem InputProps={bind("nomton1")}   desp="Amount Tolerance - Negative" path="/oldlidgrp/rec/nomton" />
	<InputItem InputProps={bind("swiadd_newnomtop")}   desp="New positive tolerance" path="/litamep/swiadd/newnomtop" />
	<InputItem InputProps={bind("swiadd_newnomton")}   desp="New negative tolerance" path="/litamep/swiadd/newnomton" />

	
	<Label itext="信用证金额" trn="litdla" />	

	
	<Label itext="最大金额" trn="litdla" />	
	<InputItem InputProps={bind("max1_cur")}  maxLength={3}  desp="Currency" path="/oldlidgrp/cbs/max/cur" />
	<InputItem InputProps={bind("max1_amt")}   desp="Balance" path="/oldlidgrp/cbs/max/amt" />

	
	<Label itext="增减金额" trn="litdla" />	
	<SelectItem InputProps={bind("swiadd_amecur")} code={CodeTable.curtxt}  desp="Currency of amended amount" path="/litamep/swiadd/amecur"/>
	<InputItem InputProps={bind("swiadd_ameamt")}   desp="Amended Amount" path="/litamep/swiadd/ameamt" />

	
	<Label itext="修改总金额" trn="litdla" />	
	<SelectItem InputProps={bind("litamep_engcur")}   desp="Engagement Currency" path="/litamep/engcur"/>
	<InputItem InputProps={bind("litamep_engamt")}   desp="change of engagement:" path="/litamep/engamt" />

	
	<Label itext="修改后金额" trn="litdla" />	
	<SelectItem InputProps={bind("swiadd_newcur")}   desp="Currency of new amount" path="/litamep/swiadd/newcur"/>
	<InputItem InputProps={bind("swiadd_newamt")}   desp="New amount" path="/litamep/swiadd/newamt" />
	<InputItem InputProps={bind("litamep_maxcur")}  maxLength={3}  desp="Currency of Maximum Amount" path="/litamep/maxcur" />
	<InputItem InputProps={bind("litamep_maxamt")}   desp="New Maximum Amount" path="/litamep/maxamt" />

	
	<Label itext="金额说明" trn="litdla" />	
	<SelectItem InputProps={bind("swiadd_nomspc")} code={CodeTable.nomspc}  desp="Amount Specification" path="/litamep/swiadd/nomspc"/>

	
	<Label itext="到期日" trn="litdla" />	
	<DatePickerItem InputProps={bind("expdat1")}  desp="Date of Expiry" path="/oldlidgrp/rec/expdat" />

	
	<Label itext="装运日" trn="litdla" />	
	<DatePickerItem InputProps={bind("shpdat1")}  desp="Shipment Date" path="/oldlidgrp/rec/shpdat" />

	
	<Label itext="新到期日" trn="litdla" />	
	<DatePickerItem InputProps={bind("swiadd_newexpdat")}  desp="New Expiry Date" path="/litamep/swiadd/newexpdat" />

	
	<Label itext="新装运日" trn="litdla" />	
	<DatePickerItem InputProps={bind("swiadd_newshpdat")}  desp="New Shipmentdate" path="/litamep/swiadd/newshpdat" />

	
	<Label itext="装船期限" trn="litdla" />	
	<TextAreaItem InputProps={bind("swiadd_shpper")} desp="Shipment Period" path="/litamep/swiadd/shpper"/>

	
	<Label itext="货物起运地" trn="litdla" />	
	<InputItem InputProps={bind("swiadd_shpfro")}  maxLength={65}  desp="Shipment from" path="/litamep/swiadd/shpfro" />

	
	<Label itext="始发（航空）站" trn="litdla" />	
	<InputItem InputProps={bind("swiadd_porloa")}  maxLength={65}  desp="Port of Loading" path="/litamep/swiadd/porloa" />

	
	<Label itext="终点（航空）站" trn="litdla" />	
	<InputItem InputProps={bind("swiadd_pordis")}  maxLength={65}  desp="Port of Discharge" path="/litamep/swiadd/pordis" />

	
	<Label itext="目的地" trn="litdla" />	
	<InputItem InputProps={bind("swiadd_shpto")}  maxLength={65}  desp="For Transportation to" path="/litamep/swiadd/shpto" />

	
	<Label itext="附加金额修改描述" trn="litdla" />	
	<TextAreaItem InputProps={bind("swiadd_addamtcov")} desp="Additional Amount Covered" path="/litamep/swiadd/addamtcov"/>
	<CheckboxItem InputProps={bind("aammod_addamtflg")}  desp="Add. Amount" path="/litp/aamp/aammod/addamtflg" />
	<InputItem InputProps={bind("max2_cur")}  maxLength={3}  desp="Currency" path="/lidgrp/cbs/max2/cur" />
	<InputItem InputProps={bind("swiadd_addamt")}   desp="Additional Amount" path="/litamep/swiadd/addamt" />
	<SelectItem InputProps={bind("litamep_ramrol")}   desp="Request of Amendment send to" path="/litamep/ramrol"/>
	<Label value={this.model.litamep_ramrollab}   desp="Label for RAMROL" path="/litamep/ramrollab" />
	<CheckboxItem InputProps={bind("litamep_cre707flg")}  desp="Create Amendment Message" path="/litamep/cre707flg" />
	<Button  type="primary"  onClick={this.onGetref} desp="Get Ref." path="/mtabut/getref">
		<Label   itext="获取"/>
	</Button>

	
	<Label itext="Reference" trn="litdla" />	
	<InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Reference" path="/lidgrp/rec/ownref" />

	
	<Label itext="Name" trn="litdla" />	
	<InputItem InputProps={bind("nam")}  maxLength={140}  desp="Externally Displayed Name to Identify the Contract" path="/lidgrp/rec/nam" />

	
	<Label itext="Applicant              Ref." trn="litdla" />	
	<InputItem InputProps={bind("pts2_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/apl/pts/ref" />

	
	<Label itext="Form of L/C" trn="litdla" />	
	<SelectItem InputProps={bind("lcrtyp")} code={CodeTable.lcrtyp}  desp="Form of Documentary Credit" path="/lidgrp/rec/lcrtyp"/>
	<InputItem InputProps={bind("pts2_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/apl/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onAplp_sel} desp="查询" path="/litp/aplp/sel">
		<Label   itext="查询"/>
	</Button>

	
	<Label itext="Nominal Amount" trn="litdla" />	
	<InputItem InputProps={bind("usr_nam")}  maxLength={8}  desp="用户ID" path="/litp//sysmod/usr/nam" />
	<CheckboxItem InputProps={bind("resflg")}  desp="Reserved Contract" path="/lidgrp/rec/resflg" />
	<TextAreaItem InputProps={bind("pts2_adrblk")} desp="SWIFT地址" path="/lidgrp/apl/pts/adrblk"/>

	
	<Label itext="Amount Tolerance +/-" trn="litdla" />	
	<SelectItem InputProps={bind("nom1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/lidgrp/cbs/nom1/cur"/>
	<InputItem InputProps={bind("nom1_amt")}   desp="Balance" path="/lidgrp/cbs/nom1/amt" />
	<CheckboxItem InputProps={bind("aammod_addamtflg")}  desp="Add. Amount" path="/litp/aamp/aammod/addamtflg" />

	
	<Label itext="Amount Specification" trn="litdla" />	
	<InputItem InputProps={bind("nomtop")}   desp="Amount Tolerance - Positive" path="/lidgrp/rec/nomtop" />
	<InputItem InputProps={bind("nomton")}   desp="Amount Tolerance - Negative" path="/lidgrp/rec/nomton" />

	
	<Label itext="Maximum Amount" trn="litdla" />	
	<SelectItem InputProps={bind("nomspc")} code={CodeTable.nomspc}  desp="Amount Specification" path="/lidgrp/rec/nomspc"/>

	
	<Label itext="L/C Issued on" trn="litdla" />	
	<SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/lidgrp/cbs/max/cur"/>
	<InputItem InputProps={bind("max_amt")}   desp="Balance" path="/lidgrp/cbs/max/amt" />

	
	<Label itext="Advising Bank     Ref." trn="litdla" />	
	<InputItem InputProps={bind("pts1_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/adv/pts/ref" />

	
	<Label itext="Date Pre-advised" trn="litdla" />	
	<DatePickerItem InputProps={bind("opndat")}  desp="Date L/C Opened/Issued" path="/lidgrp/rec/opndat" />
	<InputItem InputProps={bind("pts1_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/adv/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onAdvp_sel} desp="查询" path="/litp/advp/sel">
		<Label   itext="查询"/>
	</Button>

	
	<Label itext="Latest Shipment Date" trn="litdla" />	
	<DatePickerItem InputProps={bind("preadvdt")}  desp="Date Pre-advised" path="/lidgrp/rec/preadvdt" />
	<TextAreaItem InputProps={bind("pts1_adrblk")} desp="SWIFT地址" path="/lidgrp/adv/pts/adrblk"/>

	
	<Label itext="L/C Expiring on" trn="litdla" />	
	<DatePickerItem InputProps={bind("shpdat")}  desp="Shipment Date" path="/lidgrp/rec/shpdat" />

	
	<Label itext="in (Place)/ counters of" trn="litdla" />	
	<DatePickerItem InputProps={bind("expdat")}  desp="Date of Expiry" path="/lidgrp/rec/expdat" />

	
	<Label itext="Partial Shipment" trn="litdla" />	
	<InputItem InputProps={bind("expplc")}  maxLength={29}  desp="Place of Expiry" path="/lidgrp/rec/expplc" />

	
	<Label itext="Beneficiary           Ref." trn="litdla" />	
	<InputItem InputProps={bind("pts4_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/ben/pts/ref" />

	
	<Label itext="Confirm. Instructions" trn="litdla" />	
	<SelectItem InputProps={bind("shppar")} code={CodeTable.shppar}  desp="Partial Shipment" path="/lidgrp/rec/shppar"/>
	<InputItem InputProps={bind("pts4_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/ben/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onBenp_sel} desp="查询" path="/litp/benp/sel">
		<Label   itext="查询"/>
	</Button>

	
	<Label itext="Transshipment" trn="litdla" />	
	<SelectItem InputProps={bind("shptrs")} code={CodeTable.shppar}  desp="Transshipment" path="/lidgrp/rec/shptrs"/>
	<TextAreaItem InputProps={bind("pts4_adrblk")} desp="SWIFT地址" path="/lidgrp/ben/pts/adrblk"/>

	
	<Label itext="Responsible User" trn="litdla" />	
	<SelectItem InputProps={bind("apprul")} code={CodeTable.apprul}  desp="Applicable Rules" path="/lidgrp/rec/apprul"/>

	
	<Label itext="Current Amendment" trn="litdla" />	

	
	<Label itext="Applicable Rules" trn="litdla" />	

	
	<Label itext="Historic overview of narratives" trn="litdla" />	
	<InputItem InputProps={bind("apprultxt")}  maxLength={35}  desp="Other Applicable Rules" path="/lidgrp/rec/apprultxt" />
	<TextAreaItem InputProps={bind("swiadd_nartxt")} desp="Narrative" path="/litamep/swiadd/nartxt"/>
	<TextAreaItem InputProps={bind("blk1_narhis")} desp="Historic Overview of Narratives" path="/oldlidgrp/blk/narhis"/>

	
	<Label itext="Other Applicable Rules" trn="litdla" />	
	<SelectItem InputProps={bind("cnfdet")} code={CodeTable.cnfflg}  desp="Confirmation Instructions" path="/lidgrp/rec/cnfdet"/>
	<CheckboxItem InputProps={bind("rmbflg")}  desp="Reimbursement Information" path="/lidgrp/rec/rmbflg" />
	<CheckboxItem InputProps={bind("revflg")}  desp="Revolving Flag" path="/lidgrp/rec/revflg" />
	<CheckboxItem InputProps={bind("swiadd_nartxtflg")}  desp="Narrative modified" path="/litamep/swiadd/nartxtflg" />

	
	<Label itext="Available with" trn="litdla" />	
	<SelectItem InputProps={bind("avbwth")} code={CodeTable.avbwth}  desp="Available with" path="/lidgrp/rec/avbwth"/>

	
	<Label itext="Presentation Period" trn="litdla" />	
	<CheckboxItem InputProps={bind("blk_preperflg")}  desp="Presentation Period modified" path="/lidgrp/blk/preperflg" />
	<InputItem InputProps={bind("pts3_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/avb/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onAvbp_sel} desp="查询" path="/litp/avbp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("blk_preper")} desp="Presentation Period" path="/lidgrp/blk/preper"/>
	<Button  type="primary" icon="search" onClick={this.onPreper_buttxmsel} desp="..." path="/litp/preper/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<TextAreaItem InputProps={bind("pts3_adrblk")} desp="SWIFT地址" path="/lidgrp/avb/pts/adrblk"/>

	
	<Label itext="Available by" trn="litdla" />	
	<SelectItem InputProps={bind("avbby")} code={CodeTable.avbby0}  desp="Available by" path="/lidgrp/rec/avbby"/>

	
	<Label itext="Details" trn="litdla" />	
	<TextAreaItem InputProps={bind("blk_defdet")} desp="Deferred Payment Details" path="/lidgrp/blk/defdet"/>

	
	<Label itext="Details of Charges" trn="litdla" />	
	<TextAreaItem InputProps={bind("blk_feetxt")} desp="Additional Details to Code for Charges" path="/lidgrp/blk/feetxt"/>
	<Button  type="primary" icon="search" onClick={this.onCharia_buttxmsel} desp="..." path="/litp/charia/buttxmsel">
		<Label   itext="..."/>
	</Button>

	
	<Label itext="Drafts at" trn="litdla" />	
	<TextAreaItem InputProps={bind("blk_dftat")} desp="Drafts at" path="/lidgrp/blk/dftat"/>

	
	<Label itext="Drawee" trn="litdla" />	
	<InputItem InputProps={bind("pts6_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/drw/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onDrwp_sel} desp="查询" path="/litp/drwp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts6_adrblk")} desp="SWIFT地址" path="/lidgrp/drw/pts/adrblk"/>
	<SelectItem InputProps={bind("chato")}   desp="Own Charges Borne by" path="/lidgrp/rec/chato"/>

	
	<Label itext="Deferred Payment" trn="litdla" />	

	
	<Label itext="Country Code" trn="litdla" />	
	<SelectItem InputProps={bind("stacty")}   desp="Country Code Risk Country" path="/lidgrp/rec/stacty"/>

	
	<Label itext="Dispatch from" trn="litdla" />	
	<InputItem InputProps={bind("shpfro")}  maxLength={65}  desp="Shipment from" path="/lidgrp/rec/shpfro" />

	
	<Label itext="Tenor day" trn="litdla" />	
	<InputItem InputProps={bind("tenmaxday")}   desp="Maximum tenor in days" path="/lidgrp/rec/tenmaxday" />

	
	<Label itext="2nd Advising Bank" trn="litdla" />	

	
	<Label itext="Ref." trn="litdla" />	
	<InputItem InputProps={bind("pts_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/a2b/pts/ref" />

	
	<Label itext="Applicant's Bank" trn="litdla" />	

	
	<Label itext="Ref." trn="litdla" />	
	<InputItem InputProps={bind("pts7_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/ini/pts/ref" />

	
	<Label itext="Mixed Payment Details" trn="litdla" />	
	<InputItem InputProps={bind("pts_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/a2b/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onA2bp_sel} desp="查询" path="/litp/a2bp/sel">
		<Label   itext="查询"/>
	</Button>

	
	<Label itext="Air-/Port of Departure" trn="litdla" />	
	<InputItem InputProps={bind("porloa")}  maxLength={65}  desp="Port of Loading" path="/lidgrp/rec/porloa" />
	<InputItem InputProps={bind("pts7_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/ini/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onInip_sel} desp="查询" path="/litp/inip/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("blk_mixdet")} desp="Mixed Payment Details" path="/lidgrp/blk/mixdet"/>
	<TextAreaItem InputProps={bind("pts_adrblk")} desp="SWIFT地址" path="/lidgrp/a2b/pts/adrblk"/>
	<TextAreaItem InputProps={bind("pts7_adrblk")} desp="SWIFT地址" path="/lidgrp/ini/pts/adrblk"/>

	
	<Label itext="Air-/Port of Destination" trn="litdla" />	
	<InputItem InputProps={bind("pordis")}  maxLength={65}  desp="Port of Discharge" path="/lidgrp/rec/pordis" />

	
	<Label itext="Final Destination" trn="litdla" />	
	<InputItem InputProps={bind("shpto")}  maxLength={65}  desp="For Transportation to" path="/lidgrp/rec/shpto" />

	
	<Label itext="Shipment Period" trn="litdla" />	
	<TextAreaItem InputProps={bind("blk_shpper")} desp="Shipment Period" path="/lidgrp/blk/shpper"/>

	
	<Label itext="Reimbursement Bank" trn="litdla" />	

	
	<Label itext="Ref." trn="litdla" />	
	<InputItem InputProps={bind("pts8_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/rmb/pts/ref" />
	<Label value={this.model.litp_avblab}   desp="Label Available with Bank" path="/litp/avblab" />
	<InputItem InputProps={bind("pts3_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/avb/pts/ref" />

	
	<Label itext="Confirming Bank" trn="litdla" />	
	<InputItem InputProps={bind("pts8_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/rmb/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onRmbp_sel} desp="查询" path="/litp/rmbp/sel">
		<Label   itext="查询"/>
	</Button>
	<InputItem InputProps={bind("pts5_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/cmb/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onCmbp_sel} desp="查询" path="/litp/cmbp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts8_adrblk")} desp="SWIFT地址" path="/lidgrp/rmb/pts/adrblk"/>
	<TextAreaItem InputProps={bind("pts5_adrblk")} desp="SWIFT地址" path="/lidgrp/cmb/pts/adrblk"/>

	
	<Label itext="Description of Goods" trn="litdla" />	

	
	<Label itext="Description of Goods (History of Amendment)" trn="litdla" />	
	<TextAreaItem InputProps={bind("blk_lcrgod")} desp="Description of Gods" path="/lidgrp/blk/lcrgod"/>
	<TextAreaItem InputProps={bind("blk_lcrgodame")} desp="Description of Goods Amendment History" path="/lidgrp/blk/lcrgodame"/>

	
	<Label itext="Description of Goods (Amendment)" trn="litdla" />	
	<TextAreaItem InputProps={bind("swiadd_lcrgod")} desp="Description of Goods amendment" path="/litamep/swiadd/lcrgod"/>
	<Button  type="primary" icon="search" onClick={this.onLcrgodame_buttxmsel} desp="..." path="/litamep/lcrgodame/buttxmsel">
		<Label   itext="..."/>
	</Button>

	
	<Label itext="Documents Required" trn="litdla" />	

	
	<Label itext="Documents Required (History of Amendment)" trn="litdla" />	
	<TextAreaItem InputProps={bind("blk_lcrdoc")} desp="Documents Required" path="/lidgrp/blk/lcrdoc"/>
	<TextAreaItem InputProps={bind("blk_lcrdocame")} desp="Documents Required Amendment History" path="/lidgrp/blk/lcrdocame"/>

	
	<Label itext="Documents Required (Amendment)" trn="litdla" />	
	<TextAreaItem InputProps={bind("swiadd_lcrdoc")} desp="Documents Required amendment" path="/litamep/swiadd/lcrdoc"/>
	<Button  type="primary" icon="search" onClick={this.onLcrdocame_buttxmsel} desp="..." path="/litamep/lcrdocame/buttxmsel">
		<Label   itext="..."/>
	</Button>

	
	<Label itext="Additional Conditions" trn="litdla" />	

	
	<Label itext="Additional  Conditions (History of Amendment)" trn="litdla" />	
	<TextAreaItem InputProps={bind("blk_adlcnd")} desp="Additional Conditions" path="/lidgrp/blk/adlcnd"/>
	<TextAreaItem InputProps={bind("blk_adlcndame")} desp="Additional  Conditions Amendment History" path="/lidgrp/blk/adlcndame"/>
	<CheckboxItem InputProps={bind("redclsflg")}  desp="Red/Green Clause" path="/lidgrp/rec/redclsflg" />

	
	<Label itext="Additional Conditions (Amendment)" trn="litdla" />	
	<TextAreaItem InputProps={bind("swiadd_adlcnd")} desp="Additional Conditions amendment" path="/litamep/swiadd/adlcnd"/>
	<Button  type="primary" icon="search" onClick={this.onAdlcndame_buttxmsel} desp="..." path="/litamep/adlcndame/buttxmsel">
		<Label   itext="..."/>
	</Button>

	
	<Label itext="Instructions to Paying, Accepting, Negotiating Bank" trn="litdla" />	

	
	<Label itext="Original Text " trn="litdla" />	
	<TextAreaItem InputProps={bind("blk_insbnk")} desp="Instructions to Paying/Accepting/Negotiating Bank" path="/lidgrp/blk/insbnk"/>

	
	<Label itext="Historic Overview" trn="litdla" />	
	<TextAreaItem InputProps={bind("blk_insbnkame")} desp="Instructions to P/A/N Amendment History" path="/lidgrp/blk/insbnkame"/>

	
	<Label itext="Current Amendment" trn="litdla" />	
	<TextAreaItem InputProps={bind("swiadd_insbnk")} desp="Instruction to P/A/N Bank amendment" path="/litamep/swiadd/insbnk"/>

	
	<Label itext="Description. of Goods" trn="litdla" />	
	<TextAreaItem InputProps={bind("blk_lcrgod")} desp="Description of Gods" path="/lidgrp/blk/lcrgod"/>
	<Button  type="primary" icon="search" onClick={this.onLcrgod_buttxmsel} desp="..." path="/litp/lcrgod/buttxmsel">
		<Label   itext="..."/>
	</Button>

	
	<Label itext="Goods Code " trn="litdla" />	
	<SelectItem InputProps={bind("stagod")}   desp="Goods Code" path="/lidgrp/rec/stagod"/>

	
	<Label itext="Documents Required" trn="litdla" />	
	<TextAreaItem InputProps={bind("blk_lcrdoc")} desp="Documents Required" path="/lidgrp/blk/lcrdoc"/>
	<Button  type="primary" icon="search" onClick={this.onLcrdoc_buttxmsel} desp="..." path="/litp/lcrdoc/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<Button  type="primary"  onClick={this.onLiaall_astlia} desp="表外加载" path="/liaall/astlia">
		<Label   itext="表外加载"/>
	</Button>

	
	<Label itext="表外明细" trn="litdla" />	
	<Table rowKey="inr" columns={this.liaall_liaallgHeader}  dataSource={this.model.liaall_liaallg}   path="/liaall/liaallg"/>

	
	<Label itext="保证金明细" trn="litdla" />	
	<SelectItem InputProps={bind("liaccv_concur")} code={CodeTable.curtxt}  desp="业务结算币种" path="/liaall/liaccv/concur"/>

	
	<Label itext="业务余额" trn="litdla" />	
	<InputItem InputProps={bind("liaccv_newamt")}   desp="业务金额" path="/liaall/liaccv/newamt" />

	
	<Label itext="保证金应收比例" trn="litdla" />	
	<InputItem InputProps={bind("liaccv_cshpct")}   desp="保证金应收比例" path="/liaall/liaccv/cshpct" />

	
	<Label itext="%" trn="litdla" />	

	
	<Label itext="变动金额" trn="litdla" />	
	<InputItem InputProps={bind("liaccv_chgamt")}   desp="变动金额" path="/liaall/liaccv/chgamt" />
	<InputItem InputProps={bind("liaccv_relcshpct")}   desp="保证金实收比例" path="/liaall/liaccv/relcshpct" />

	
	<Label itext="保证金实收比例" trn="litdla" />	

	
	<Label itext="%" trn="litdla" />	

	
	<Label itext="应收/支保证金" trn="litdla" />	
	<InputItem InputProps={bind("liaccv_pctresamt")}   desp="应收/支保证金" path="/liaall/liaccv/pctresamt" />
	<Button  type="primary"  onClick={this.onLiaccv_recalccv} desp="汇率重算" path="/liaall/liaccv/recalccv">
		<Label   itext="汇率重算"/>
	</Button>
	<Table rowKey="inr" columns={this.liaccv_liaccvgHeader}  dataSource={this.model.liaccv_liaccvg}   path="/liaall/liaccv/liaccvg"/>

	
	<Label itext="保证金合计" trn="litdla" />	
	<InputItem InputProps={bind("liaccv_totcovamt")}   desp="保证金合计" path="/liaall/liaccv/totcovamt" />

	
	<Label itext="业务余额" trn="litdla" />	

	
	<Label itext="保证金应收比例" trn="litdla" />	

	
	<Label itext="%" trn="litdla" />	

	
	<Label itext="变动金额" trn="litdla" />	

	
	<Label itext="保证金实收比例" trn="litdla" />	

	
	<Label itext="%" trn="litdla" />	

	
	<Label itext="应收/支保证金" trn="litdla" />	

	
	<Label itext="保证金合计" trn="litdla" />	

	
	<Label itext="结算金额" trn="litdla" />	
	<SelectItem InputProps={bind("setmod_doccur")} code={CodeTable.curtxt}  desp="document currency" path="/setmod/doccur"/>
	<InputItem InputProps={bind("setmod_docamt")}   desp="document amount" path="/setmod/docamt" />
	<Button  type="primary"  onClick={this.onSetmod_feedet} desp="重算金额" path="/setmod/feedet">
		<Label   itext="重算金额"/>
	</Button>
	<Button  type="primary"  onClick={this.onSetmod_ast} desp="加载账务" path="/setmod/ast">
		<Label   itext="加载账务"/>
	</Button>

	
	<Label itext="FEEMAC" trn="litdla" />	
	<InputItem InputProps={bind("setmod_feemac")}  maxLength={200}  desp="FEEMAC" path="/setmod/feemac" />
	<Button  type="primary"  onClick={this.onSetmod_recal} desp="重算账务" path="/setmod/recal">
		<Label   itext="重算账务"/>
	</Button>

	
	<Label itext="费用明细" trn="litdla" />	

	
	<Label itext="SETMAC" trn="litdla" />	
	<InputItem InputProps={bind("setmod_setmac")}  maxLength={200}  desp="SETMAC" path="/setmod/setmac" />
	<Table rowKey="inr" columns={this.fegmod_feslstHeader}  dataSource={this.model.fegmod_feslst}   path="/setmod/setfeg/fegmod/feslst"/>

	
	<Label itext="账务明细" trn="litdla" />	
	<Table rowKey="inr" columns={this.glgmod_glslstHeader}  dataSource={this.model.glgmod_glslst}   path="/setmod/setglg/glgmod/glslst"/>

	
	<Label itext="会计分录" trn="litdla" />	
	<Button  type="primary"  onClick={this.onGlemod_rebook} desp="分录加载" path="/setmod/glemod/rebook">
		<Label   itext="分录加载"/>
	</Button>
	<Table rowKey="inr" columns={this.glemod_glelstHeader}  dataSource={this.model.glemod_glelst}   path="/setmod/glemod/glelst"/>

	
	<Label itext="面函码值" trn="litdla" />	
	<InputItem InputProps={bind("trndoc_doccod")}  maxLength={16}  desp="面函码值" path="/trnmod/trndoc/doccod" />

	
	<Label itext="Per Medium" trn="litdla" />	
	<InputItem InputProps={bind("trndoc_cortyp")}  maxLength={3}  desp="Per Medium" path="/trnmod/trndoc/cortyp" />
	<Button  type="primary"  onClick={this.onTrndoc_reldoc} desp="面函加载" path="/trnmod/trndoc/reldoc">
		<Label   itext="面函加载"/>
	</Button>
	<Button  type="primary"  onClick={this.onTrndoc_butshw} desp="show doc." path="/trnmod/trndoc/butshw">
		<Label   itext="展示"/>
	</Button>

	
	<Label itext="面函路径" trn="litdla" />	
	<InputItem InputProps={bind("trndoc_docpth")}  maxLength={100}  desp="面函路径" path="/trnmod/trndoc/docpth" />
	<Table rowKey="inr" columns={this.docmod_doclstHeader}  dataSource={this.model.docmod_doclst}   path="/trnmod/trndoc/docmod/doclst"/>

	
	<Label itext="唯一编号" trn="litdla" />	
	<InputItem InputProps={bind("spt_inr")}  maxLength={8}  desp="唯一编号" path="/sysmod/spt/inr" />

	
	<Label itext="A" trn="litdla" />	
	<InputItem InputProps={bind("trndoc_doctrestm")}   desp="Document tree" path="/trnmod/trndoc/doctrestm" />
	<Button  type="primary"  onClick={this.onTrndoc_butadd} desp="Details" path="/trnmod/trndoc/butadd">
		<Label   itext="B"/>
	</Button>
	<Button  type="primary"  onClick={this.onTrndoc_butnew} desp="New Entry" path="/trnmod/trndoc/butnew">
		<Label   itext="C"/>
	</Button>
	<Button  icon="delete" onClick={this.onTrndoc_butdel} desp="Delete Entry" path="/trnmod/trndoc/butdel">
		<Label   itext="D"/>
	</Button>
	<CheckboxItem InputProps={bind("trndoc_shwinc")}  desp="Show Incoming Messages" path="/trnmod/trndoc/shwinc" />
	<CheckboxItem InputProps={bind("trndoc_shwout")}  desp="Show Outgoing Messages" path="/trnmod/trndoc/shwout" />
	<CheckboxItem InputProps={bind("trndoc_shwoutint")}  desp="Show Internal Messages" path="/trnmod/trndoc/shwoutint" />
	<Button  type="primary"  onClick={this.onTrndoc_butatt} desp="Attach" path="/trnmod/trndoc/butatt">
		<Label   itext="E"/>
	</Button>
	<InputItem InputProps={bind("trndoc_condocstm")}   desp="Connected Documents" path="/trnmod/trndoc/condocstm" />
	<Button  type="primary" icon="save"
		  onClick={this.onSav} desp="Save" path="/mtabut/sav">
		<Label   itext="提交"/>
	</Button>
	<Button  type="primary"  onClick={this.onChk} desp="Check" path="/mtabut/chk">
		<Label   itext="检核"/>
	</Button>
	<Button  type="primary"  onClick={this.onPed} desp="暂存" path="/mtabut/ped">
		<Label   itext="暂存"/>
	</Button>
	<Button  type="primary"  onClick={this.onExi} desp="Exit" path="/mtabut/exi">
		<Label   itext="退出"/>
	</Button>
		</div>
		)
	}
}
